-- This file will be generated at release time. Don't edit it manually.
ndless_revision="0"
-- The contents of this file are subject to the Mozilla Public
-- License Version 1.1 (the "License"); you may not use this file
-- except in compliance with the License. You may obtain a copy of
-- the License at http://www.mozilla.org/MPL/
--
--  The Original Code is Ndless code.
--
-- The Initial Developer of the Original Code is Jim Bauwens.
-- Portions created by the Initial Developer are Copyright (C) 2013-2014
-- the Initial Developer. All Rights Reserved.
 
-- Contributor(s): Excale and others.

-------------------
-- Set API Level --
-------------------

platform.apilevel = '1.0'

-----------------------------
-- Constants and variables --
-----------------------------

-- ndless_revision is set by ndless_version.lua
NDLESS_VERSION = "Ndless 3.6 rev. " .. ndless_revision

-- for help / strings
help = false
b  = string.uchar(10003)
bb = ":( " -- string.uchar(215)

-- Will be corrected at runtime
DEVICE_MODEL   = ""
DEVICE_HAS_CAS = false
DEVICE_MIN_OS  = ""
NO_TRICK = false

----------------------
-- Extend some libs --
----------------------

do
    function invalidateAll()
        Widget:setFocus(false)
        Widget:setFocus(true)
    end

    function AddToGC(key, func)
        local gcMetatable = getmetatable(platform.gc())
        gcMetatable[key] = func
    end

    local function drawBWHorizontalGradient(gc, from, to, x, y, w, h)
        local diff = to - from
        for i = 1, h do
            local shade = math.floor((i * diff) / h)
            gc:setColorRGB(shade, shade, shade)
            gc:fillRect(x, y + i - 1, w, 1)
        end
    end

    local function drawStringMiddle(gc, str, x, y, w, h)
        local sw = gc:getStringWidth(str)
        local sh = gc:getStringHeight(str)
        gc:drawString(str, x + (w - sw) / 2, y + (h - sh) / 2, "top")
    end

    AddToGC("drawBWHorizontalGradient", drawBWHorizontalGradient)
    AddToGC("drawStringMiddle", drawStringMiddle)
end

-----------------------
-- General functions --
-----------------------

local counter = 0
function refreshAtStart()
    counter = (counter + 1) % 100
    if counter == 5 then
        on.getFocus()
    end
end

function imgTest()
    image.new("\255\255\255\127\1\0\0\0\0\0\0\0\0\0\0\0\16\0\1\0")
end

function getVersion()
    local version

    -- is color?
    local color = platform.isColorDisplay()

    -- is cas?
    local _, caserr = math.eval("solve()")
    local has_cas = caserr == 930

    -- is computer?
    local hw
    if not platform.hw then
        hw = 0
    else
        hw = platform.hw()
    end
    local computer = hw == 7

    -- is tablet?
    local tablet = platform.isTabletModeRendering and platform.isTabletModeRendering()

    -- So what's the device
    local device

    if tablet then
        device = "TABLET"
    elseif computer then
        device = "COMPUTER"
    elseif color then
        device = "CX"
    else
        device = "BW"
    end

    local min_os
    if Widget then
        if pcall(imgTest) then
            min_os = "3.2"
        else
            min_os = "3.6"
        end
    else
        min_os = "0.0"
    end

    return device, has_cas, min_os
end

---------------
-- Main view --
---------------

function drawMainView(gc)
    gc:drawBWHorizontalGradient(0, 80, 0, 1, 320, 21)
    gc:setColorRGB(50, 50, 50)
    gc:fillRect(0, 22, 320, 1)

    gc:setColorRGB(0xCC, 0xCC, 0xCC)
    gc:fillRect(0, 23, 320, 1)

    gc:setColorRGB(0, 0, 0)
    gc:fillRect(0, 24, 320, 240 - 24)

    gc:setColorRGB(0xDD, 0xDD, 0xFF)
    gc:setFont("sansserif", "r", 12)

    if not ndless then
        gc:drawStringMiddle(L"installTitle", 0, 0, 320, 24)
    else
        gc:drawStringMiddle(L"uninstallTitle", 0, 0, 320, 24)
    end

    gc:setColorRGB(0xDD, 0xFF, 0xDD)
    gc:setFont("sansserif", "r", 9)

    if help then
        if not (DEVICE_MIN_OS == "3.6") then
            for i = 1, 3 do
                gc:drawString(L("helpErr" .. i), 5, 30 + (i - 1) * 14, "top")
            end
        else
            for i = 1, 6 do
                gc:drawString(L("help" .. i), 5, 30 + (i - 1) * 14, "top")
            end

            gc:setColorRGB(0, 0, 0)

            for i = 0, 20 do
                gc:setColorRGB(4 * i, 4 * i, 4 * i)
                gc:drawLine(20, i + 114, 150, i + 114)
            end

            gc:setFont("serif", "r", 13)
            gc:setColorRGB(255, 255, 255)
            gc:drawString(string.uchar(61703), 25, 110, "top")
            gc:drawLine(20, 134, 150, 134)

            gc:setFont("serif", "r", 11)
            gc:setColorRGB(0, 255, 0)
            gc:drawString("Ndless installed!", 46, 114, "top")

            gc:setFont("sansserif", "r", 9)
            gc:setColorRGB(0xDD, 0xFF, 0xDD)
            gc:drawString(L"success", 5, 134, "top")
			gc:drawString(L"nonpersistent", 5, 148, "top")
        end
    else
        if NO_TRICK then
            gc:drawString(L"notCalc", 5, 30, "top")
        elseif not (DEVICE_MIN_OS == "3.6") then
            gc:drawString(L"not36", 5, 30, "top")
        elseif ndless then
            gc:drawString(L"uninst1", 5, 30, "top")
            gc:drawString(L"uninst2", 5, 44, "top")
            gc:drawString(L"uninst3", 5, 58, "top")
        else
            gc:drawString(L"inst1", 5, 30, "top")
            gc:drawString(L"inst2", 5, 44, "top")
            gc:drawString(L"inst3", 5, 58, "top")
        end

        gc:setColorRGB(0xCC, 0xCC, 0xCC)
        gc:fillRect(0, 82, 320, 1)

        gc:setColorRGB(0xDD, 0xFF, 0xDD)
        gc:setFont("sansserif", "r", 9)

        gc:drawString(b .. " " .. NDLESS_VERSION .. " ", 5, 86, "top")
        gc:drawString((NO_TRICK and bb or b) .. " TI-Nspire " .. DEVICE_MODEL .. (DEVICE_HAS_CAS and " CAS" or ""), 5, 100, "top")
        gc:setColorRGB(0xCC, 0xCC, 0xCC)
        gc:fillRect(0, 122, 320, 1)

        gc:setColorRGB(0xDD, 0xFF, 0xDD)
        gc:setFont("sansserif", "r", 9)
        local b = string.uchar(61712)

        if DEVICE_MODEL == "BW" then
            gc:setColorRGB(0xFF, 0xFF, 0xFF)
        else
            gc:setColorRGB(0xFF, 0xAA, 0xAA)
        end
        gc:drawString(L"wantHelp", 5, 126, "top")
    end

    gc:setColorRGB(0xCC, 0xCC, 0xCC)
    gc:fillRect(0, 166, 320, 1)

    if not NO_TRICK then -- to go well with non-displayed credits because of weird tincs stuff...
        gc:setColorRGB(0xFF, 0xDD, 0xDD)
        gc:drawStringMiddle(L"credits", 5, 168, 320, 20)
    end
end

------------------
-- Credits code --
------------------

local credits = {
    "ExtendeD",
    "bsl",
    "Goplat",
    "Lionel Debroux",
    "Levak",
    "Excale",
    "Vogtinator",
    "Critor",
    "Tangrs",
    "Jim Bauwens"
}

local PAUSE_SPOT = 0
local DELAY = 40
local STEP = 4
local START = -320
local END = 320

local cr = 1
local cp = START
local mc = 0

function drawCredits(gc)
    gc:setColorRGB(0, 0, 0)
    gc:fillRect(0, 0, 320, 240)

    gc:setColorRGB(0xFF, 0xDD, 0xDD)
    gc:setFont("serif", "r", 14)
    gc:drawStringMiddle(credits[cr], cp, 170, 320, 20)
end

---------------------
-- Draw everything --
---------------------

local is_invalidated = true

function on.paint(gc)
    if is_invalidated or NO_TRICK then
        is_invalidated = NO_TRICK

        gc:begin()
        drawMainView(gc)
        gc:finish()
    end

    if not NO_TRICK then drawCredits(gc) end
end

function on.getFocus()
    is_invalidated = true
    platform.window:invalidate()
end

---------------------------------
-- Setup timer for credits bar --
---------------------------------

function on.create()
    timer.start(0.01)
end

function on.timer()
    if mc > 0 then
        mc = mc - 1
    elseif cp == -PAUSE_SPOT then
        cp = cp + STEP
        mc = DELAY
    elseif cp >= END then
        cp = START
        cr = cr + 1
        if cr > #credits then cr = 1 end
    else
        cp = cp + STEP
    end

    platform.window:invalidate(0, 160, 320, 80)
    refreshAtStart()
end

-----------------
-- key presses --
-----------------

function on.charIn(ch)
    if ch == "u" and ndless then
        ndless.uninst()
    end
    if ch == "h" then
        help = not help
    end
    platform.window:invalidate()
end

function on.enterKey()
    help = false
    platform.window:invalidate()
end
on.escapeKey = on.enterKey

------------------------------
-- localize all the strings --
------------------------------
strings = {
    ["inst1"] = {
        en = b .. " Press [MENU] to install Ndless",
        fr = b .. " Appuyez sur [MENU] pour installer Ndless"
    },
    ["inst2"] = {
        en = b .. " Installation will start immediately",
        fr = b .. " L’installation commencera immédiatement"
    },
    ["inst3"] = {
        en = b .. " Enjoy!",
        -- good enough.
    },
    ["uninst1"] = {
        en = b .. " Press [u] to uninstall Ndless",
        fr = b .. " Appuyez sur [u] pour désinstaller Ndless",
    },
    ["uninst2"] = {
        en = b .. " The device will reboot",
        fr = b .. " L'unité va rebooter"
    },
    ["uninst3"] = {
        en = b .. " To reinstall just reopen this document!",
        fr = b .. " Pour réinstaller, réouvrez ce document !",
    },
    ["credits"] = {
        en = "Developers & Testers",
        fr = "Développeurs & Testeurs"
    },
    ["wantHelp"] = {
        en = b .. " First time? Press [h] for a mini-tutorial!",
        fr = b .. " Première fois? Appuyez sur [h] pour un mini-tuto !",
    },
    ["success"] = {
        en = " ... Congratulations, you’ve successfully installed Ndless!",
        fr = " ... Félicitations, vous avez installé Ndless avec succès !",
    },
    ["nonpersistent"] = {
        en = "Ndless will have to be reinstalled after each reboot.",
        fr = "Ndless devra être réinstallé après chaque reboot.",
    },
    ["helpErr1"] = {
        en = bb .. "  Your device is not running OS 3.6!",
        fr = bb .. "  Votre unité n'est pas en OS 3.6 !",
    },
    ["helpErr2"] = {
        en = bb .. "  For more informations, please visit",
        fr = bb .. "  Pour plus d'informations, veuillez visiter",
    },
    ["helpErr3"] = {
        en = bb .. "  http://ndlessly.wordpress.com/ndless-user-guide",
        -- no translation
    },
    ["help1"] = {
        en = b .. " First, make sure 'ndless_resources_3.6.tns' is in the",
        fr = b .. " Déjà, soyez sûr que 'ndless_resources_3.6.tns' soit dans",
    },
    ["help2"] = {
        en = "  'ndless' folder, otherwise, the install will fail",
        fr = "      le dossier 'ndless', sinon ça ne marchera pas",
    },
    ["help3"] = {
        en = b .. " To install Ndless, simply press [MENU]",
        fr = b .. " Pour installer Ndless, appuyez juste sur [MENU]",
    },
    ["help4"] = {
        en = b .. " The screen should display a clock for a few seconds,",
        fr = b .. " L’écran va afficher l’horloge pendant quelques",
    },
    ["help5"] = {
        en = "  then the home screen should appear",
        fr = "      secondes, puis l'écran d'accueil devrait apparaître",
    },
    ["help6"] = {
        en = b .. " If you see this at the top-left of the screen...:",
        fr = b .. " Si vous voyez ceci en haut à gauche de l'écran... :",
    },
    ["installTitle"] = {
        en = "Install Ndless",
        fr = "Installer Ndless"
    },
    ["uninstallTitle"] = {
        en = "Uninstall Ndless",
        fr = "Désinstaller Ndless"
    },
    ["notCalc"] = {
        en = bb .. " This is not a TI-Nspire handheld...",
        fr = bb .. " Ceci n'est pas une calculatrice..."
    },
    ["not36"] = {
        en = bb .. " Your calculator is not running OS 3.6",
        fr = bb .. " Votre calculatrice n'a pas l'OS 3.6"
    },
    -- todo : add more languages ?
}

lang = nil
function L(key)
    lang = lang or locale.name()
    local tbl = strings[key]
    return tbl and (tbl[lang] or tbl[lang:sub(1, 2)]) or tbl["en"]
end


----------------------
-- Ndless installer --
----------------------

function on.resize()
    local device, has_cas, min_os = getVersion()

    DEVICE_MODEL = device
    DEVICE_HAS_CAS = has_cas
    DEVICE_MIN_OS = min_os
    NO_TRICK = (DEVICE_MODEL == "COMPUTER" or DEVICE_MODEL == "TABLET")

    if min_os == "3.6" and s then
        if device == "BW" and not has_cas then
            s = s .. s_ncas
        elseif device == "BW" and has_cas then
            s = s .. s_cas
        elseif device == "CX" and not has_cas then
            s = s .. s_ncascx
        elseif device == "CX" and has_cas then
            s = s .. s_cascx
        end

        if not ndless and s then
            toolpalette.register{ { s } }
        end
    end

    -- avoid running again
    on.resize = nil
end

-- The "s" string building code goes here as produced by MakeLuaInst

u=string.uchar
s=""
s=s..u(0x1000)..u(0xe10f)..u(0x1004)..u(0xe221)..u(0xf001)..u(0xe129)..u(0xe546)..u(0xe3a0)..u(0xe601)..u(0xe24e)..u(0xe701)..u(0xe28e)..u(0x0058)..u(0xe28f)..u(0x0b2a)..u(0xe280)..u(0x0080)..u(0xe280)..u(0x30b2)..u(0xe0d0)..u(0x40b2)..u(0xe0d0)..u(0x5084)..u(0xe080)..u(0x600e)..u(0xe1a0)..u(0x7004)..u(0xe495)..u(0x7004)..u(0xe486)..u(0x3004)..u(0xe253)..u(0xfffb)..u(0x1aff)..u(0x8009)..u(0xe3a0)..u(0x20b2)..u(0xe0d0)..u(0x200e)..u(0xe082)..u(0x90b0)..u(0xe1d2)..u(0x0010)..u(0xe319)..u(0x30b0)..u(0x11c2)..u(0x80b0)..u(0x01c2)..u(0x4001)..u(0xe254)
s=s..u(0xfff7)..u(0x1aff)..u(0xff7a)..u(0xee17)..u(0xfffd)..u(0x1aff)..u(0x3f17)..u(0xee07)..u(0xf00e)..u(0xe1a0)..string.rep(u(0x0101),21504)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)
s=s..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x0004)..u(0x1180)..u(0x28d8)..u(0x0054)..u(0x0036)..u(0x0038)..u(0x003a)..u(0x003e)..u(0x0094)..u(0x0118)..u(0x0160)..u(0x0240)..u(0x0248)..u(0x02ce)..u(0x02d2)..u(0x02d6)..u(0x02d8)..u(0x02da)..u(0x02de)..u(0x02f2)..u(0x0312)..u(0x0316)..u(0x0330)..u(0x0334)..u(0x0336)..u(0x035c)..u(0x03c0)
s=s..u(0x03e2)..u(0x03e4)..u(0x03e6)..u(0x03f0)..u(0x0410)..u(0x1176)..u(0x1178)..u(0x117a)..u(0x117c)..u(0x1180)..u(0x1188)..u(0x118c)..u(0x1190)..u(0x11aa)..u(0x11ce)..u(0x145a)..u(0x1460)..u(0x1466)..u(0x1472)..u(0x147e)..u(0x148a)..u(0x1496)..u(0x14a2)..u(0x15b6)..u(0x1626)..u(0x1684)..u(0x1698)..u(0x16ac)..u(0x172a)..u(0x172e)..u(0x1746)..u(0x1752)..u(0x1756)..u(0x1762)..u(0x26d4)..u(0x2756)..u(0x2758)..u(0x275a)..u(0x27b6)..u(0x27b8)..u(0x27ba)..u(0x28ae)..u(0x28b0)..u(0x28b2)..u(0x28b4)..u(0x28b6)..u(0x28b8)..u(0x28ba)..u(0x28bc)..u(0x28be)
s=s..u(0x28c0)..u(0x28c2)..u(0x28c4)..u(0x28c6)..u(0x28ca)..u(0x28cc)..u(0x28ce)..u(0x28d0)..u(0x28d2)..u(0x28d4)..u(0x28d6)..u(0x4ff0)..u(0xe92d)..u(0x2028)..u(0xe59f)..u(0x2002)..u(0xe08f)..u(0x3014)..u(0xe24f)..u(0x5024)..u(0xe59f)..u(0x5001)..u(0xe255)..u(0x4000)..u(0xa592)..u(0x4003)..u(0xa084)..u(0x4004)..u(0xa482)..u(0xfffa)..u(0xaaff)..u(0xd008)..u(0xe58f)..u(0x00f9)..u(0xeb00)..u(0x8ff0)..u(0xe8bd)..u(0x28b8)..string.rep(u(0xffff),3)..u(0x0001)..u(0xffff)..u(0x2003)..u(0xe3c2)..u(0x2002)..u(0xe080)..u(0x0002)..u(0xe150)..u(0xff1e)..u(0x012f)..u(0x1004)
s=s..u(0xe480)..u(0xfffb)..u(0xeaff)..u(0x3034)..u(0xe59f)..u(0x2020)..u(0xe3a0)..u(0x2004)..u(0xe583)..u(0x2001)..u(0xe3a0)..u(0x206c)..u(0xe583)..u(0x0010)..u(0xe583)..u(0x2070)..u(0xe593)..u(0x0001)..u(0xe312)..u(0xfffc)..u(0x1aff)..u(0x2010)..u(0xe59f)..u(0x1010)..u(0xe582)..u(0x2070)..u(0xe593)..u(0x0001)..u(0xe312)..u(0xfffc)..u(0x1aff)..u(0xff1e)..u(0xe12f)..u(0xffff)..u(0x9005)..u(0xff7a)..u(0xee17)..u(0xfffd)..u(0x1aff)..u(0x3000)..u(0xe3a0)..u(0x3f17)..u(0xee07)..u(0xff1e)..u(0xe12f)..u(0x41f0)..u(0xe92d)..u(0x8214)..u(0xe59f)..u(0xd030)
s=s..u(0xe24d)..u(0x3000)..u(0xe3a0)..u(0x3004)..u(0xe58d)..u(0x09a9)..u(0xeb00)..u(0x7204)..u(0xe59f)..u(0x8008)..u(0xe08f)..u(0x7007)..u(0xe08f)..u(0x1008)..u(0xe1a0)..u(0x41f8)..u(0xe59f)..u(0x500c)..u(0xe28d)..u(0x4004)..u(0xe08f)..u(0x3000)..u(0xe1a0)..u(0x0007)..u(0xe1a0)..u(0xff33)..u(0xe12f)..u(0x31e4)..u(0xe59f)..u(0x4003)..u(0xe794)..u(0x6000)..u(0xe250)..u(0x0024)..u(0x1a00)..u(0x099a)..u(0xeb00)..u(0x71d4)..u(0xe59f)..u(0x1008)..u(0xe1a0)..u(0x7007)..u(0xe08f)..u(0x3000)..u(0xe1a0)..u(0x0007)..u(0xe1a0)..u(0xff33)..u(0xe12f)..u(0xffff)
s=s..u(0xe350)..u(0x001b)..u(0x1a00)..u(0x3000)..u(0xe594)..u(0x000c)..u(0xe58d)..u(0x0006)..u(0xe353)..u(0x31ac)..u(0x059f)..u(0x0007)..u(0x0a00)..u(0x0007)..u(0xe353)..u(0x31a4)..u(0x059f)..u(0x0004)..u(0x0a00)..u(0x11a0)..u(0xe59f)..u(0x21a0)..u(0xe59f)..u(0x0008)..u(0xe353)..u(0x3002)..u(0x01a0)..u(0x3001)..u(0x11a0)..u(0x0194)..u(0xe59f)..u(0x200a)..u(0xe3a0)..u(0x1005)..u(0xe1a0)..u(0xffff)..u(0xe08f)..u(0xff33)..u(0xe12f)..u(0x2184)..u(0xe59f)..u(0x3000)..u(0xe3a0)..u(0x3008)..u(0xe58d)..u(0x3008)..u(0xe59d)..u(0x0002)..u(0xe153)..u(0x0029)
s=s..u(0xca00)..u(0x3008)..u(0xe59d)..u(0x3001)..u(0xe283)..u(0x3008)..u(0xe58d)..u(0xfff8)..u(0xeaff)..u(0x1005)..u(0xe1a0)..u(0x0007)..u(0xe1a0)..u(0x095c)..u(0xeb00)..u(0x3000)..u(0xe594)..u(0x0020)..u(0xe59d)..u(0x0006)..u(0xe353)..u(0x3148)..u(0x059f)..u(0x0007)..u(0x0a00)..u(0x0007)..u(0xe353)..u(0x3140)..u(0x059f)..u(0x0004)..u(0x0a00)..u(0x113c)..u(0xe59f)..u(0x213c)..u(0xe59f)..u(0x0008)..u(0xe353)..u(0x3002)..u(0x01a0)..u(0x3001)..u(0x11a0)..u(0xff33)..u(0xe12f)..u(0x2000)..u(0xe594)..u(0x1020)..u(0xe59d)..u(0x0006)..u(0xe352)..u(0x5120)
s=s..u(0x059f)..u(0x7000)..u(0xe1a0)..u(0x0026)..u(0x1a00)..u(0x3006)..u(0xe1a0)..u(0x2001)..u(0xe3a0)..u(0x0007)..u(0xe1a0)..u(0xff35)..u(0xe12f)..u(0x3000)..u(0xe594)..u(0x0006)..u(0xe353)..u(0x3100)..u(0x059f)..u(0x0026)..u(0x1a00)..u(0x0006)..u(0xe1a0)..u(0xff33)..u(0xe12f)..u(0x7004)..u(0xe287)..u(0xff9e)..u(0xebff)..u(0x1004)..u(0xe28d)..u(0x0001)..u(0xe3a0)..u(0xff37)..u(0xe12f)..u(0x2000)..u(0xe594)..u(0x10dc)..u(0xe59f)..u(0x30dc)..u(0xe59f)..u(0x1001)..u(0xe08f)..u(0x3003)..u(0xe08f)..u(0x2006)..u(0xe242)..u(0xffff)..u(0xe591)..u(0x2102)
s=s..u(0xe793)..u(0xffff)..u(0xe582)..u(0x2000)..u(0xe594)..u(0x1004)..u(0xe591)..u(0x2006)..u(0xe242)..u(0x3102)..u(0xe793)..u(0x1004)..u(0xe583)..u(0xff8c)..u(0xebff)..u(0xe004)..u(0xe52d)..u(0xe0c4)..u(0xe28f)..u(0xe000)..u(0xe59e)..u(0xe004)..u(0xe52d)..u(0x6000)..u(0xe89d)..u(0x5fff)..u(0xe8bd)..u(0x098b)..u(0xea00)..u(0xd030)..u(0xe28d)..u(0x81f0)..u(0xe8bd)..u(0x0007)..u(0xe352)..u(0x5084)..u(0x059f)..u(0xffd5)..u(0x0aff)..u(0x3080)..u(0xe59f)..u(0x0008)..u(0xe352)..u(0x507c)..u(0xe59f)..u(0x5003)..u(0x01a0)..u(0xffd0)..u(0xeaff)..u(0x0007)
s=s..u(0xe353)..u(0x3070)..u(0x059f)..u(0xffd5)..u(0x0aff)..u(0x106c)..u(0xe59f)..u(0x206c)..u(0xe59f)..u(0x0008)..u(0xe353)..u(0x3002)..u(0x01a0)..u(0x3001)..u(0x11a0)..u(0xffcf)..u(0xeaff)..u(0x2714)..u(0xffff)..u(0x2713)..u(0xffff)..u(0x27e4)..string.rep(u(0xffff),3)..u(0x2702)..u(0xffff)..u(0xc78c)..u(0x100c)..u(0xca44)..u(0x100c)..u(0xc030)..u(0x100c)..u(0xbd48)..u(0x100c)..u(0x26df)..u(0xffff)..u(0xe0ff)..u(0x05f5)..u(0x8f6c)..u(0x103f)..u(0x99ac)..u(0x103f)..u(0x7860)..u(0x103f)..u(0x6df0)..u(0x103f)..u(0xeb78)..u(0x103f)..u(0xe248)..u(0x103f)..u(0x2674)
s=s..u(0xffff)..u(0x258c)..u(0xffff)..u(0xf5b8)..u(0x103f)..u(0xc9fc)..u(0x103f)..u(0xd46c)..u(0x103f)..u(0xec88)..u(0x103f)..u(0xcb3c)..u(0x103f)..u(0xc0cc)..u(0x103f)..u(0xffff)..u(0xea00)..string.rep(u(0xffff),2)..u(0x5fff)..u(0xe92d)..u(0x0004)..u(0xe50d)..u(0x0014)..u(0xe24f)..u(0xd000)..u(0xe580)..u(0x0004)..u(0xe51d)..u(0xff56)..u(0xeaff)..u(0x3004)..u(0xe59f)..u(0x2002)..u(0xe3a0)..u(0x2008)..u(0xe583)..u(0xffff)..u(0x900a)..u(0x2201)..u(0xe3a0)..u(0x1070)..u(0xe59f)..u(0x2020)..u(0xe592)..u(0x306c)..u(0xe59f)..u(0x0001)..u(0xe152)..u(0x1068)..u(0xe59f)
s=s..u(0x3003)..u(0xe08f)..u(0x3001)..u(0xe793)..u(0x000d)..u(0x0a00)..u(0x0004)..u(0x8a00)..u(0x1058)..u(0xe59f)..u(0x0001)..u(0xe152)..u(0x2008)..u(0x03a0)..u(0x000b)..u(0x0a00)..u(0x000c)..u(0xea00)..u(0x1048)..u(0xe59f)..u(0x0001)..u(0xe152)..u(0x0006)..u(0x0a00)..u(0x1e56)..u(0xe281)..u(0x0001)..u(0xe152)..u(0x2007)..u(0x03a0)..u(0x0003)..u(0x0a00)..u(0x0004)..u(0xea00)..u(0x2006)..u(0xe3a0)..u(0xffff)..u(0xea00)..u(0x2009)..u(0xe3a0)..u(0x2000)..u(0xe583)..u(0xff1e)..u(0xe12f)..u(0x3018)..u(0xe59f)..u(0x2002)..u(0xe3a0)..u(0x2008)..u(0xe583)
s=s..u(0x5bb0)..u(0x1037)..u(0x2548)..string.rep(u(0xffff),3)..u(0x5620)..u(0x1037)..u(0x6090)..u(0x1037)..u(0xffff)..u(0x900a)..u(0x3014)..u(0xe59f)..u(0x2014)..u(0xe59f)..u(0x2c00)..u(0xe583)..u(0x2000)..u(0xe3a0)..u(0x2008)..u(0xe583)..u(0x2c00)..u(0xe583)..u(0xff1e)..u(0xe12f)..u(0xffff)..u(0x9006)..u(0xe551)..u(0x1acc)..u(0x4ff0)..u(0xe92d)..u(0x4d50)..u(0xe59f)..u(0xd014)..u(0xe24d)..u(0xfff2)..u(0xebff)..u(0xffcc)..u(0xebff)..u(0xfff0)..u(0xebff)..u(0x3d40)..u(0xe59f)..u(0x4004)..u(0xe08f)..u(0x3003)..u(0xe794)..u(0x2000)..u(0xe3e0)..u(0x3000)..u(0xe593)
s=s..u(0x3006)..u(0xe243)..u(0x0001)..u(0xe353)..u(0x3004)..u(0xe58d)..u(0x3337)..u(0xe3a0)..u(0x0005)..u(0xca00)..u(0x200c)..u(0xe583)..u(0x2000)..u(0xe10f)..u(0x2080)..u(0xe3c2)..u(0xf002)..u(0xe121)..u(0x3028)..u(0xe593)..u(0x0011)..u(0xea00)..u(0x1d04)..u(0xe59f)..u(0x2014)..u(0xe583)..u(0x2000)..u(0xe3a0)..u(0x3001)..u(0xe3a0)..u(0x2008)..u(0xe581)..u(0x300c)..u(0xe581)..u(0x2028)..u(0xe581)..u(0x302c)..u(0xe581)..u(0x180b)..u(0xe281)..u(0x2008)..u(0xe581)..u(0x300c)..u(0xe581)..u(0x2028)..u(0xe581)..u(0x302c)..u(0xe581)..u(0x1801)..u(0xe281)
s=s..u(0x2008)..u(0xe581)..u(0x300c)..u(0xe581)..u(0x2028)..u(0xe581)..u(0x302c)..u(0xe581)..u(0x2cc0)..u(0xe59f)..u(0x3018)..u(0xe592)..u(0x3060)..u(0xe3c3)..u(0x3018)..u(0xe582)..u(0x3000)..u(0xe3a0)..u(0x300c)..u(0xe58d)..u(0x300c)..u(0xe59d)..u(0x0801)..u(0xe353)..u(0x300c)..u(0xd59d)..u(0x3001)..u(0xd283)..u(0xfff9)..u(0xdaff)..u(0x220b)..u(0xe3a0)..u(0x3140)..u(0xe592)..u(0x3001)..u(0xe3c3)..u(0x3140)..u(0xe582)..u(0x232d)..u(0xe3a0)..u(0x3140)..u(0xe582)..u(0x3000)..u(0xe3a0)..u(0x300c)..u(0xe58d)..u(0x300c)..u(0xe59d)..u(0x0801)..u(0xe353)
s=s..u(0x300c)..u(0xd59d)..u(0x3001)..u(0xd283)..u(0xfff9)..u(0xdaff)..u(0x320b)..u(0xe3a0)..u(0x2140)..u(0xe593)..u(0x2002)..u(0xe382)..u(0x2140)..u(0xe583)..u(0x4140)..u(0xe593)..u(0x4002)..u(0xe214)..u(0xfffc)..u(0x1aff)..u(0x2c48)..u(0xe59f)..u(0x320b)..u(0xe3a0)..u(0x21a4)..u(0xe583)..u(0x3004)..u(0xe59d)..u(0x0001)..u(0xe353)..u(0x0008)..u(0xda00)..u(0x1004)..u(0xe1a0)..u(0x00ff)..u(0xe3a0)..u(0xfebf)..u(0xebff)..u(0x1001)..u(0xe3a0)..u(0x0004)..u(0xe3a0)..u(0xfebc)..u(0xebff)..u(0x3c1c)..u(0xe59f)..u(0x4030)..u(0xe583)..u(0x406c)..u(0xe583)
s=s..u(0x3c14)..u(0xe59f)..u(0x2001)..u(0xe3a0)..u(0x200c)..u(0xe583)..u(0x2c0c)..u(0xe59f)..u(0x3000)..u(0xe3a0)..u(0x300c)..u(0xe582)..u(0x3040)..u(0xe582)..u(0xa003)..u(0xe1a0)..u(0x3004)..u(0xe59d)..u(0x0003)..u(0xe353)..u(0xf103)..u(0x908f)..u(0x083a)..u(0xea00)..u(0x0002)..u(0xea00)..u(0x019f)..u(0xea00)..u(0x046e)..u(0xea00)..u(0x0606)..u(0xea00)..u(0x3bdc)..u(0xe59f)..u(0x5000)..u(0xe3e0)..u(0x5bf0)..u(0xe583)..u(0xaad8)..u(0xe583)..u(0xab10)..u(0xe583)..u(0xab5c)..u(0xe583)..u(0x2018)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0bc0)..u(0xe59f)
s=s..u(0xfe99)..u(0xebff)..u(0x3bbc)..u(0xe59f)..u(0x2fd3)..u(0xe3a0)..u(0x5e3c)..u(0xe583)..u(0x3ac5)..u(0xe283)..u(0xae54)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xab5c)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0ba0)..u(0xe59f)..u(0xfe8f)..u(0xebff)..u(0x3b9c)..u(0xe59f)..u(0x2b9c)..u(0xe59f)..u(0xa7dc)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa4e4)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0b8c)..u(0xe59f)..u(0xfe87)..u(0xebff)..u(0x3b88)..u(0xe59f)..u(0x2f89)..u(0xe3a0)..u(0xab84)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa88c)..u(0xe583)..u(0x1000)..u(0xe3a0)
s=s..u(0x0b74)..u(0xe59f)..u(0xfe7f)..u(0xebff)..u(0x3b70)..u(0xe59f)..u(0x2e27)..u(0xe3a0)..u(0xaa60)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa768)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0b5c)..u(0xe59f)..u(0xfe77)..u(0xebff)..u(0x3b58)..u(0xe59f)..u(0x2f81)..u(0xe3a0)..u(0xa354)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa05c)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0b44)..u(0xe59f)..u(0xfe6f)..u(0xebff)..u(0x3b40)..u(0xe59f)..u(0x2b40)..u(0xe59f)..u(0xaed4)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xabdc)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0b30)..u(0xe59f)
s=s..u(0xfe67)..u(0xebff)..u(0x3b2c)..u(0xe59f)..u(0x2e25)..u(0xe3a0)..u(0xa070)..u(0xe583)..u(0x3a01)..u(0xe283)..u(0xad78)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0b18)..u(0xe59f)..u(0xfe5f)..u(0xebff)..u(0x3b14)..u(0xe59f)..u(0x2f62)..u(0xe3a0)..u(0xa57c)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa284)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0b00)..u(0xe59f)..u(0xfe57)..u(0xebff)..u(0x3afc)..u(0xe59f)..u(0x2f99)..u(0xe3a0)..u(0xa814)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa51c)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0ae8)..u(0xe59f)..u(0xfe4f)..u(0xebff)
s=s..u(0x3ae4)..u(0xe59f)..u(0x2f62)..u(0xe3a0)..u(0xa54c)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa254)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0ad0)..u(0xe59f)..u(0xfe47)..u(0xebff)..u(0x3acc)..u(0xe59f)..u(0x2f9b)..u(0xe3a0)..u(0xa9d8)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa6e0)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0ab8)..u(0xe59f)..u(0xfe3f)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0aac)..u(0xe59f)..u(0xfe3b)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0aa0)..u(0xe59f)..u(0xfe37)..u(0xebff)..u(0x2040)..u(0xe3a0)
s=s..u(0x1000)..u(0xe3a0)..u(0x0a94)..u(0xe59f)..u(0xfe33)..u(0xebff)..u(0x3a90)..u(0xe59f)..u(0x2a90)..u(0xe59f)..u(0x6004)..u(0xe3a0)..u(0x2a5c)..u(0xe583)..u(0xaa3c)..u(0xe583)..u(0x6a44)..u(0xe583)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0a78)..u(0xe59f)..u(0xfe29)..u(0xebff)..u(0x2a74)..u(0xe59f)..u(0x1001)..u(0xe3a0)..u(0x0a70)..u(0xe59f)..u(0x7a70)..u(0xe59f)..u(0x4001)..u(0xe3a0)..u(0x8a6c)..u(0xe59f)..u(0x2ab0)..u(0xe583)..u(0x2008)..u(0xe3a0)..u(0xfe20)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0a58)..u(0xe59f)
s=s..u(0x4b94)..u(0xe583)..u(0x7ac8)..u(0xe583)..u(0xaad8)..u(0xe583)..u(0xaaec)..u(0xe583)..u(0xab00)..u(0xe583)..u(0xab14)..u(0xe583)..u(0xab28)..u(0xe583)..u(0xab3c)..u(0xe583)..u(0xab50)..u(0xe583)..u(0xab64)..u(0xe583)..u(0xab78)..u(0xe583)..u(0xab8c)..u(0xe583)..u(0xfe10)..u(0xebff)..u(0x2dfc)..u(0xe59f)..u(0x1000)..u(0xe3a0)..u(0x0a1c)..u(0xe59f)..u(0x2bec)..u(0xe583)..u(0x2df4)..u(0xe59f)..u(0x2c70)..u(0xe583)..u(0x2df0)..u(0xe59f)..u(0x2c74)..u(0xe583)..u(0x206f)..u(0xe3a0)..u(0x2c78)..u(0xe583)..u(0x2030)..u(0xe3a0)..u(0xfe04)..u(0xebff)
s=s..u(0x2030)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x09f0)..u(0xe59f)..u(0xfe00)..u(0xebff)..u(0x201e)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x09e4)..u(0xe59f)..u(0x2f90)..u(0xe583)..u(0x2040)..u(0xe3a0)..u(0xfdfa)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x09d0)..u(0xe59f)..u(0xfdf6)..u(0xebff)..u(0x39cc)..u(0xe59f)..u(0x2102)..u(0xe3a0)..u(0x218c)..u(0xe583)..u(0x2a02)..u(0xe3a0)..u(0x4188)..u(0xe583)..u(0x2190)..u(0xe583)..u(0xaf54)..u(0xe583)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x09ac)..u(0xe59f)..u(0xfdeb)..u(0xebff)
s=s..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x09a0)..u(0xe59f)..u(0xfde7)..u(0xebff)..u(0x399c)..u(0xe59f)..u(0x299c)..u(0xe59f)..u(0x1000)..u(0xe3a0)..u(0x27d4)..u(0xe583)..u(0x0994)..u(0xe59f)..u(0x2020)..u(0xe3a0)..u(0xfde0)..u(0xebff)..u(0x298c)..u(0xe59f)..u(0x1000)..u(0xe3a0)..u(0x0988)..u(0xe59f)..u(0x29b8)..u(0xe583)..u(0x2040)..u(0xe3a0)..u(0xfdda)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0974)..u(0xe59f)..u(0xfdd6)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0968)..u(0xe59f)..u(0xfdd2)..u(0xebff)
s=s..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x095c)..u(0xe59f)..u(0xfdce)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0950)..u(0xe59f)..u(0xfdca)..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0944)..u(0xe59f)..u(0xfdc6)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0938)..u(0xe59f)..u(0xfdc2)..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x092c)..u(0xe59f)..u(0xfdbe)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0920)..u(0xe59f)..u(0xfdba)..u(0xebff)..u(0x2008)..u(0xe3a0)
s=s..u(0x1000)..u(0xe3a0)..u(0x0914)..u(0xe59f)..u(0xfdb6)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0908)..u(0xe59f)..u(0xfdb2)..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x08fc)..u(0xe59f)..u(0xfdae)..u(0xebff)..u(0x2014)..u(0xe3a0)..u(0x1008)..u(0xe1a0)..u(0x08f0)..u(0xe59f)..u(0xfdaa)..u(0xebff)..u(0x38ec)..u(0xe59f)..u(0x1005)..u(0xe1a0)..u(0x4580)..u(0xe583)..u(0x2010)..u(0xe3a0)..u(0x08e0)..u(0xe59f)..u(0xfda4)..u(0xebff)..u(0x38dc)..u(0xe59f)..u(0x1005)..u(0xe1a0)..u(0x564c)..u(0xe583)..u(0x3a01)..u(0xe283)
s=s..u(0x4f08)..u(0xe583)..u(0x2008)..u(0xe3a0)..u(0x08c8)..u(0xe59f)..u(0xfd9c)..u(0xebff)..u(0x38c4)..u(0xe59f)..u(0x20ff)..u(0xe3a0)..u(0x2860)..u(0xe583)..u(0x2003)..u(0xe3a0)..u(0x4820)..u(0xe583)..u(0x2864)..u(0xe583)..u(0xa86c)..u(0xe583)..u(0x206c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x08a4)..u(0xe59f)..u(0xfd91)..u(0xebff)..u(0x206c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0898)..u(0xe59f)..u(0xaa58)..u(0xe583)..u(0xfd8c)..u(0xebff)..u(0x3890)..u(0xe59f)..u(0x2020)..u(0xe3a0)..u(0x4e30)..u(0xe583)..u(0x5f04)..u(0xe583)..u(0x4f08)..u(0xe583)
s=s..u(0x1000)..u(0xe3a0)..u(0x087c)..u(0xe59f)..u(0xfd84)..u(0xebff)..u(0x3878)..u(0xe59f)..u(0x2c48)..u(0xe59f)..u(0xa418)..u(0xe583)..u(0x2ed4)..u(0xe583)..u(0xafa4)..u(0xe583)..u(0x2002)..u(0xe3a0)..u(0x3a01)..u(0xe283)..u(0x21c0)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x2010)..u(0xe3a0)..u(0x0854)..u(0xe59f)..u(0xfd78)..u(0xebff)..u(0x2850)..u(0xe59f)..u(0x1004)..u(0xe1a0)..u(0x084c)..u(0xe59f)..u(0x2220)..u(0xe583)..u(0xa21c)..u(0xe583)..u(0x7224)..u(0xe583)..u(0x2008)..u(0xe3a0)..u(0xfd70)..u(0xebff)..u(0x2838)..u(0xe59f)..u(0x1000)..u(0xe3a0)
s=s..u(0x0834)..u(0xe59f)..u(0x238c)..u(0xe583)..u(0x2014)..u(0xe282)..u(0x23a0)..u(0xe583)..u(0xa268)..u(0xe583)..u(0xa2fc)..u(0xe583)..u(0xa338)..u(0xe583)..u(0xa388)..u(0xe583)..u(0xa39c)..u(0xe583)..u(0x2020)..u(0xe3a0)..u(0xfd63)..u(0xebff)..u(0x1005)..u(0xe1a0)..u(0x200c)..u(0xe3a0)..u(0x0804)..u(0xe59f)..u(0xfd5f)..u(0xebff)..u(0x2e19)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x07f8)..u(0xe59f)..u(0x5023)..u(0xe3a0)..u(0x88dc)..u(0xe583)..u(0x8d24)..u(0xe583)..u(0x37ec)..u(0xe59f)..u(0x41ec)..u(0xe583)..u(0x3a03)..u(0xe283)..u(0xa180)..u(0xe583)
s=s..u(0xfd54)..u(0xebff)..u(0x37dc)..u(0xe59f)..u(0x2040)..u(0xe3a0)..u(0xab24)..u(0xe583)..u(0xab54)..u(0xe583)..u(0x3a6f)..u(0xe283)..u(0x44f0)..u(0xe583)..u(0x1bb0)..u(0xe59f)..u(0x07c4)..u(0xe59f)..u(0xfd4b)..u(0xebff)..u(0x37c0)..u(0xe59f)..u(0x2040)..u(0xe3a0)..u(0x5060)..u(0xe583)..u(0x1ba4)..u(0xe59f)..u(0x07b4)..u(0xe59f)..u(0xfd45)..u(0xebff)..u(0x402a)..u(0xe3a0)..u(0x2024)..u(0xe3a0)..u(0x1b84)..u(0xe59f)..u(0x07a4)..u(0xe59f)..u(0x4260)..u(0xe583)..u(0xfd3f)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x1b7c)..u(0xe59f)..u(0x0794)..u(0xe59f)
s=s..u(0xfd3b)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x1b60)..u(0xe59f)..u(0x0788)..u(0xe59f)..u(0xfd37)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x1b5c)..u(0xe59f)..u(0x077c)..u(0xe59f)..u(0x5844)..u(0xe583)..u(0xfd32)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x1b3c)..u(0xe59f)..u(0x076c)..u(0xe59f)..u(0x4a44)..u(0xe583)..u(0xfd2d)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x1b34)..u(0xe59f)..u(0x075c)..u(0xe59f)..u(0xfd29)..u(0xebff)..u(0x3758)..u(0xe59f)..u(0x2a10)..u(0xe59f)..u(0xa0b4)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x074c)..u(0xe59f)..u(0xfd23)..u(0xebff)
s=s..u(0x206c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0740)..u(0xe59f)..u(0xfd1f)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0734)..u(0xe59f)..u(0xfd1b)..u(0xebff)..u(0x3730)..u(0xe59f)..u(0x6018)..u(0xe583)..u(0x3a03)..u(0xe283)..u(0xac80)..u(0xe583)..u(0xac90)..u(0xe583)..u(0xaca0)..u(0xe583)..u(0xacb0)..u(0xe583)..u(0xacc0)..u(0xe583)..u(0xacd0)..u(0xe583)..u(0xace0)..u(0xe583)..u(0xacf0)..u(0xe583)..u(0xad00)..u(0xe583)..u(0xad10)..u(0xe583)..u(0xad20)..u(0xe583)..u(0xad30)..u(0xe583)..u(0xad40)..u(0xe583)..u(0xad50)..u(0xe583)
s=s..u(0xad60)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa818)..u(0xe583)..u(0xa824)..u(0xe583)..u(0x06b1)..u(0xea00)..u(0x36dc)..u(0xe59f)..u(0x5000)..u(0xe3e0)..u(0x5650)..u(0xe583)..u(0xa538)..u(0xe583)..u(0xa570)..u(0xe583)..u(0xa5bc)..u(0xe583)..u(0x2018)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x06c0)..u(0xe59f)..u(0xfcfb)..u(0xebff)..u(0x36bc)..u(0xe59f)..u(0x20c8)..u(0xe3a0)..u(0x589c)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x06b0)..u(0xe59f)..u(0xfcf5)..u(0xebff)..u(0x36ac)..u(0xe59f)..u(0x27e4)..u(0xe59f)..u(0xa9fc)..u(0xe583)..u(0x1000)..u(0xe3a0)
s=s..u(0x06a0)..u(0xe59f)..u(0xfcef)..u(0xebff)..u(0x369c)..u(0xe59f)..u(0x2f81)..u(0xe3a0)..u(0xadb4)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xaabc)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0688)..u(0xe59f)..u(0xfce7)..u(0xebff)..u(0x3684)..u(0xe59f)..u(0x2520)..u(0xe59f)..u(0xa934)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa63c)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0670)..u(0xe59f)..u(0xfcdf)..u(0xebff)..u(0x366c)..u(0xe59f)..u(0x2e25)..u(0xe3a0)..u(0xaad0)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa7d8)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0658)..u(0xe59f)
s=s..u(0xfcd7)..u(0xebff)..u(0x3654)..u(0xe59f)..u(0x2f99)..u(0xe3a0)..u(0xa274)..u(0xe583)..u(0x3a01)..u(0xe283)..u(0xaf7c)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0640)..u(0xe59f)..u(0xfccf)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0634)..u(0xe59f)..u(0xfccb)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0628)..u(0xe59f)..u(0xfcc7)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x061c)..u(0xe59f)..u(0xfcc3)..u(0xebff)..u(0x3618)..u(0xe59f)..u(0x2004)..u(0xe3a0)..u(0x24a4)..u(0xe583)..u(0x2610)..u(0xe59f)
s=s..u(0xa49c)..u(0xe583)..u(0x24bc)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x2040)..u(0xe3a0)..u(0x0600)..u(0xe59f)..u(0xfcb9)..u(0xebff)..u(0x25fc)..u(0xe59f)..u(0x1001)..u(0xe3a0)..u(0x05f8)..u(0xe59f)..u(0x75f8)..u(0xe59f)..u(0x4001)..u(0xe3a0)..u(0x65f4)..u(0xe59f)..u(0x2510)..u(0xe583)..u(0x2008)..u(0xe3a0)..u(0xfcb0)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x05e0)..u(0xe59f)..u(0x45f4)..u(0xe583)..u(0x7528)..u(0xe583)..u(0xa538)..u(0xe583)..u(0xa54c)..u(0xe583)..u(0xa560)..u(0xe583)..u(0xa574)..u(0xe583)..u(0xa588)..u(0xe583)
s=s..u(0xa59c)..u(0xe583)..u(0xa5b0)..u(0xe583)..u(0xa5c4)..u(0xe583)..u(0xa5d8)..u(0xe583)..u(0xa5ec)..u(0xe583)..u(0xfca0)..u(0xebff)..u(0x283c)..u(0xe59f)..u(0x1000)..u(0xe3a0)..u(0x05a4)..u(0xe59f)..u(0x264c)..u(0xe583)..u(0x2065)..u(0xe3a0)..u(0x2658)..u(0xe583)..u(0x2830)..u(0xe59f)..u(0xa65c)..u(0xe583)..u(0x26d4)..u(0xe583)..u(0x206f)..u(0xe3a0)..u(0x26d8)..u(0xe583)..u(0x2030)..u(0xe3a0)..u(0xfc93)..u(0xebff)..u(0x2030)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0574)..u(0xe59f)..u(0xfc8f)..u(0xebff)..u(0x201e)..u(0xe3a0)..u(0x1000)..u(0xe3a0)
s=s..u(0x0568)..u(0xe59f)..u(0x29f0)..u(0xe583)..u(0x2040)..u(0xe3a0)..u(0xfc89)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0554)..u(0xe59f)..u(0xfc85)..u(0xebff)..u(0x2102)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0548)..u(0xe59f)..u(0x2bec)..u(0xe583)..u(0x2a02)..u(0xe3a0)..u(0x4be8)..u(0xe583)..u(0x2bf0)..u(0xe583)..u(0x3538)..u(0xe59f)..u(0x2040)..u(0xe3a0)..u(0xaa44)..u(0xe583)..u(0xfc7a)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0524)..u(0xe59f)..u(0xfc76)..u(0xebff)..u(0x3520)..u(0xe59f)..u(0x2520)..u(0xe59f)
s=s..u(0x1000)..u(0xe3a0)..u(0x2b98)..u(0xe583)..u(0x0518)..u(0xe59f)..u(0x2040)..u(0xe3a0)..u(0xfc6f)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0508)..u(0xe59f)..u(0xfc6b)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x04fc)..u(0xe59f)..u(0xfc67)..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x04f0)..u(0xe59f)..u(0xfc63)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x04e4)..u(0xe59f)..u(0xfc5f)..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x04d8)..u(0xe59f)..u(0xfc5b)..u(0xebff)
s=s..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x04cc)..u(0xe59f)..u(0xfc57)..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x04c0)..u(0xe59f)..u(0xfc53)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x04b4)..u(0xe59f)..u(0xfc4f)..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x04a8)..u(0xe59f)..u(0xfc4b)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x049c)..u(0xe59f)..u(0xfc47)..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0490)..u(0xe59f)..u(0xfc43)..u(0xebff)..u(0x2014)..u(0xe3a0)
s=s..u(0x1006)..u(0xe1a0)..u(0x0484)..u(0xe59f)..u(0xfc3f)..u(0xebff)..u(0x3480)..u(0xe59f)..u(0x1005)..u(0xe1a0)..u(0x4760)..u(0xe583)..u(0x3902)..u(0xe283)..u(0x582c)..u(0xe583)..u(0x2008)..u(0xe3a0)..u(0x046c)..u(0xe59f)..u(0xfc37)..u(0xebff)..u(0x3468)..u(0xe59f)..u(0x20ff)..u(0xe3a0)..u(0x2a40)..u(0xe583)..u(0x2003)..u(0xe3a0)..u(0x4a00)..u(0xe583)..u(0x2a44)..u(0xe583)..u(0xaa4c)..u(0xe583)..u(0x206c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0448)..u(0xe59f)..u(0xfc2c)..u(0xebff)..u(0x206c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x043c)..u(0xe59f)
s=s..u(0xac38)..u(0xe583)..u(0xfc27)..u(0xebff)..u(0x3434)..u(0xe59f)..u(0x2020)..u(0xe3a0)..u(0x4010)..u(0xe583)..u(0x50e4)..u(0xe583)..u(0x40e8)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0420)..u(0xe59f)..u(0xfc1f)..u(0xebff)..u(0x341c)..u(0xe59f)..u(0x26b4)..u(0xe59f)..u(0xa5f8)..u(0xe583)..u(0x3a01)..u(0xe283)..u(0x20b4)..u(0xe583)..u(0x2002)..u(0xe3a0)..u(0x23a0)..u(0xe583)..u(0xa184)..u(0xe583)..u(0x2010)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x03f8)..u(0xe59f)..u(0xfc13)..u(0xebff)..u(0x23f4)..u(0xe59f)..u(0x1004)..u(0xe1a0)..u(0x03f0)..u(0xe59f)
s=s..u(0x2400)..u(0xe583)..u(0xa3fc)..u(0xe583)..u(0x7404)..u(0xe583)..u(0x2008)..u(0xe3a0)..u(0xfc0b)..u(0xebff)..u(0x23dc)..u(0xe59f)..u(0x1000)..u(0xe3a0)..u(0x03d8)..u(0xe59f)..u(0x256c)..u(0xe583)..u(0x2014)..u(0xe282)..u(0x2580)..u(0xe583)..u(0xa448)..u(0xe583)..u(0xa4dc)..u(0xe583)..u(0xa518)..u(0xe583)..u(0xa568)..u(0xe583)..u(0xa57c)..u(0xe583)..u(0x2020)..u(0xe3a0)..u(0xfbfe)..u(0xebff)..u(0x1005)..u(0xe1a0)..u(0x200c)..u(0xe3a0)..u(0x03a8)..u(0xe59f)..u(0xfbfa)..u(0xebff)..u(0x2e19)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x039c)..u(0xe59f)
s=s..u(0x5023)..u(0xe3a0)..u(0x4ac4)..u(0xe583)..u(0x6abc)..u(0xe583)..u(0x6f04)..u(0xe583)..u(0x338c)..u(0xe59f)..u(0x43cc)..u(0xe583)..u(0x3a03)..u(0xe283)..u(0xa360)..u(0xe583)..u(0xfbee)..u(0xebff)..u(0x337c)..u(0xe59f)..u(0x2040)..u(0xe3a0)..u(0xad04)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0x4058)..u(0xe583)..u(0x161c)..u(0xe59f)..u(0x0368)..u(0xe59f)..u(0xfbe6)..u(0xebff)..u(0x3364)..u(0xe59f)..u(0x2040)..u(0xe3a0)..u(0x5bd4)..u(0xe583)..u(0x1610)..u(0xe59f)..u(0x0358)..u(0xe59f)..u(0xfbe0)..u(0xebff)..u(0x402a)..u(0xe3a0)..u(0x2024)..u(0xe3a0)
s=s..u(0x15f0)..u(0xe59f)..u(0x0348)..u(0xe59f)..u(0x4dd4)..u(0xe583)..u(0xfbda)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x15e8)..u(0xe59f)..u(0x0338)..u(0xe59f)..u(0xfbd6)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x15cc)..u(0xe59f)..u(0x032c)..u(0xe59f)..u(0xfbd2)..u(0xebff)..u(0x3328)..u(0xe59f)..u(0x2024)..u(0xe3a0)..u(0x53b8)..u(0xe583)..u(0x15c0)..u(0xe59f)..u(0x031c)..u(0xe59f)..u(0xfbcc)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x15a4)..u(0xe59f)..u(0x0310)..u(0xe59f)..u(0x45b8)..u(0xe583)..u(0xfbc7)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x159c)..u(0xe59f)
s=s..u(0x0300)..u(0xe59f)..u(0xfbc3)..u(0xebff)..u(0x247c)..u(0xe59f)..u(0x1000)..u(0xe3a0)..u(0x02f4)..u(0xe59f)..u(0xac28)..u(0xe583)..u(0xfbbe)..u(0xebff)..u(0x206c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x02e4)..u(0xe59f)..u(0xfbba)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x02d8)..u(0xe59f)..u(0xfbb6)..u(0xebff)..u(0x32d4)..u(0xe59f)..u(0xa780)..u(0xe583)..u(0xa78c)..u(0xe583)..u(0x055e)..u(0xea00)..u(0x248c)..string.rep(u(0xffff),4)..u(0x9001)..u(0xffff)..u(0x900b)..u(0x1120)..u(0x003c)..u(0xffff)..u(0x9005)..u(0xffff)..u(0x9009)..u(0xffff)
s=s..u(0x900e)..u(0xd000)..u(0x10af)..u(0xdc20)..u(0x10af)..u(0x1000)..u(0x10b0)..u(0x8b74)..u(0x10bc)..u(0xe000)..u(0x10bc)..u(0x0474)..u(0xffff)..u(0x04fc)..u(0x10bd)..u(0x4000)..u(0x10c1)..u(0x68a4)..u(0x10c1)..u(0xc000)..u(0x10c1)..u(0xe780)..u(0x10c1)..u(0xa000)..u(0x10c6)..u(0xc074)..u(0x10c6)..u(0xd000)..u(0x10c6)..u(0x0408)..u(0xffff)..u(0xfbf4)..u(0x10c6)..u(0x2000)..u(0x10c7)..u(0x3d90)..u(0x10c7)..u(0x2000)..u(0x10c9)..u(0x429c)..u(0x10c9)..u(0xa000)..u(0x10c9)..u(0xc534)..u(0x10c9)..u(0xc000)..u(0x10cb)..u(0xe26c)..u(0x10cb)..u(0x4000)
s=s..u(0x10cc)..u(0x66f8)..u(0x10cc)..u(0x9714)..u(0x10d1)..u(0xa970)..u(0x10d1)..u(0xa9d0)..u(0x10d1)..u(0xa000)..u(0x10d1)..u(0x8f78)..u(0x109c)..u(0xaa6c)..u(0x10d1)..u(0xd8d0)..u(0x1008)..u(0xaac0)..u(0x10d1)..u(0x51cc)..u(0x10a6)..u(0x036c)..u(0x10f8)..u(0xabac)..u(0x10d1)..u(0xacc8)..u(0x10d1)..u(0xae04)..u(0x10d1)..u(0xafbc)..u(0x10d1)..u(0xb060)..u(0x10d1)..u(0xb000)..u(0x10d1)..u(0xbf70)..u(0x10d1)..u(0xc014)..u(0x10d1)..u(0xe000)..u(0x10d1)..u(0xe9ec)..u(0x1011)..u(0xe7e4)..u(0x10d1)..u(0x7778)..u(0x10a1)..u(0xea44)..u(0x10d1)..u(0xeb08)
s=s..u(0x10d1)..u(0xeb74)..u(0x10d1)..u(0xebbc)..u(0x10d1)..u(0xebcc)..u(0x10d1)..u(0xec14)..u(0x10d1)..u(0xec24)..u(0x10d1)..u(0xec6c)..u(0x10d1)..u(0xec7c)..u(0x10d1)..u(0xecc4)..u(0x10d1)..u(0xecd4)..u(0x10d1)..u(0xed1c)..u(0x10d1)..u(0xed2c)..u(0x10d1)..u(0x3000)..u(0x10d2)..u(0xb4e8)..u(0x10d2)..u(0xb000)..u(0x10d2)..u(0xcf0c)..u(0x10d2)..u(0xd000)..u(0x10d2)..u(0xd8ac)..u(0x10d2)..u(0xda98)..u(0x10d2)..u(0x1000)..u(0x10d3)..u(0x338c)..u(0x10d3)..u(0x3000)..u(0x10d3)..u(0x41d4)..u(0x10d3)..u(0x421c)..u(0x10d3)..u(0x4258)..u(0x10d3)..u(0x4388)
s=s..u(0x10d3)..u(0x43c8)..u(0x10d3)..u(0x43e8)..u(0x10d3)..u(0x8198)..u(0x10d3)..u(0x5000)..u(0x10d3)..u(0xc000)..u(0x10d3)..u(0x1020)..u(0x10e3)..u(0x1000)..u(0x10e3)..u(0x1220)..u(0x10e3)..u(0x1420)..u(0x10e3)..u(0x1620)..u(0x10e3)..u(0x1820)..u(0x10e3)..u(0x1a20)..u(0x10e3)..u(0x1c20)..u(0x10e3)..u(0x1e20)..u(0x10e3)..u(0x2000)..u(0x10e3)..u(0x20d0)..u(0x10e3)..u(0x2634)..u(0x10e3)..u(0x2ba8)..u(0x10e3)..u(0x3000)..u(0x10e3)..u(0xd000)..u(0x10b3)..u(0xd680)..u(0x10b3)..u(0x1000)..u(0x10b4)..u(0x1974)..u(0x10b4)..u(0xa000)..u(0x10b6)..u(0xaa14)
s=s..u(0x10b6)..u(0x9000)..u(0x10ca)..u(0xbad4)..u(0x10ca)..u(0xd000)..u(0x10ca)..u(0xf654)..u(0x10ca)..u(0x1000)..u(0x10cb)..u(0x37f0)..u(0x10cb)..u(0xa000)..u(0x10cd)..u(0xbf94)..u(0x10cd)..u(0x9174)..u(0x10d5)..u(0xa3d0)..u(0x10d5)..u(0xa430)..u(0x10d5)..u(0xa000)..u(0x10d5)..u(0xd8e8)..u(0x10a0)..u(0xa4cc)..u(0x10d5)..u(0xd82c)..u(0x1008)..u(0xa520)..u(0x10d5)..u(0x9f3c)..u(0x10aa)..u(0x4364)..u(0x10f5)..u(0xa60c)..u(0x10d5)..u(0xa728)..u(0x10d5)..u(0xa864)..u(0x10d5)..u(0xaa1c)..u(0x10d5)..u(0xaac0)..u(0x10d5)..u(0xba60)..u(0x10d5)..u(0xb000)
s=s..u(0x10d5)..u(0xbb04)..u(0x10d5)..u(0xe000)..u(0x10d5)..u(0xc464)..u(0x10a5)..u(0xec24)..u(0x10d5)..u(0xece8)..u(0x10d5)..u(0xed54)..u(0x10d5)..u(0xed9c)..u(0x10d5)..u(0xedac)..u(0x10d5)..u(0xedf4)..u(0x10d5)..u(0xee04)..u(0x10d5)..u(0xee4c)..u(0x10d5)..u(0xee5c)..u(0x10d5)..u(0xeea4)..u(0x10d5)..u(0xeeb4)..u(0x10d5)..u(0xeefc)..u(0x10d5)..u(0xef0c)..u(0x10d5)..u(0x3000)..u(0x10d6)..u(0xd0ec)..u(0x10d6)..u(0xd000)..u(0x10d6)..u(0xda8c)..u(0x10d6)..u(0xdc78)..u(0x10d6)..u(0x2000)..u(0x10d7)..u(0x356c)..u(0x10d7)..u(0x3000)..u(0x10d7)..u(0x43b4)
s=s..u(0x10d7)..u(0x43fc)..u(0x10d7)..u(0x4438)..u(0x10d7)..u(0x4568)..u(0x10d7)..u(0x45a8)..u(0x10d7)..u(0x45c8)..u(0x10d7)..u(0x8378)..u(0x10d7)..u(0x5000)..u(0x10d7)..u(0xc000)..u(0x10d7)..u(0x3b94)..u(0x10e0)..u(0x3000)..u(0x10e0)..u(0x3d94)..u(0x10e0)..u(0x3f94)..u(0x10e0)..u(0x4194)..u(0x10e0)..u(0x4394)..u(0x10e0)..u(0x4000)..u(0x10e0)..u(0x4594)..u(0x10e0)..u(0x4794)..u(0x10e0)..u(0x4994)..u(0x10e0)..u(0x4c44)..u(0x10e0)..u(0x51a8)..u(0x10e0)..u(0x571c)..u(0x10e0)..u(0xb000)..u(0x10e0)..u(0xa000)..u(0x10ad)..u(0xa448)..u(0x10ad)..u(0xe000)
s=s..u(0x10ad)..u(0xe73c)..u(0x10ad)..u(0x7000)..u(0x10b0)..u(0x2004)..u(0xffff)..u(0x77dc)..u(0x10b0)..u(0xffff)..u(0x10bd)..u(0x0798)..u(0xffff)..u(0x1fd0)..u(0x10bd)..u(0x7000)..u(0x10da)..u(0x04b4)..u(0xffff)..u(0x9a40)..u(0x10da)..u(0x1000)..u(0x10db)..u(0x0cdc)..u(0xffff)..u(0x2e20)..u(0x10db)..u(0xb000)..u(0x10db)..u(0x05b4)..u(0xffff)..u(0xda74)..u(0x10db)..u(0x9000)..u(0x10dc)..u(0x04d8)..u(0xffff)..u(0xaf54)..u(0x10dc)..u(0xc000)..u(0x10e3)..u(0x05f8)..u(0xffff)..u(0xe25c)..u(0x10e3)..u(0x4120)..u(0x10fd)..u(0x5378)..u(0x10fd)..u(0x53d4)
s=s..u(0x10fd)..u(0x5000)..u(0x10fd)..u(0xa644)..u(0x109a)..u(0xcf00)..u(0x1008)..u(0x54c8)..u(0x10fd)..u(0x55b4)..u(0x10fd)..u(0xe4ac)..u(0x111c)..u(0x56d0)..u(0x10fd)..u(0x580c)..u(0x10fd)..u(0x59c4)..u(0x10fd)..u(0x5a1c)..u(0x10fd)..u(0x5a7c)..u(0x10fd)..u(0x6978)..u(0x10fd)..u(0x6000)..u(0x10fd)..u(0x69d0)..u(0x10fd)..u(0x6a20)..u(0x10fd)..u(0x9000)..u(0x10fd)..u(0x8e68)..u(0x109f)..u(0x944c)..u(0x10fd)..u(0x9498)..u(0x10fd)..u(0x9514)..u(0x10fd)..u(0x957c)..u(0x10fd)..u(0x95c4)..u(0x10fd)..u(0x95d4)..u(0x10fd)..u(0x961c)..u(0x10fd)..u(0x962c)
s=s..u(0x10fd)..u(0x9674)..u(0x10fd)..u(0x9684)..u(0x10fd)..u(0x96cc)..u(0x10fd)..u(0x96dc)..u(0x10fd)..u(0x9724)..u(0x10fd)..u(0x9734)..u(0x10fd)..u(0xdfff)..u(0x10fd)..u(0x5ef0)..u(0x10fe)..u(0x6000)..u(0x10fe)..u(0x7914)..u(0x10fe)..u(0x8000)..u(0x10fe)..u(0x82b4)..u(0x10fe)..u(0x84a0)..u(0x10fe)..u(0xc000)..u(0x10fe)..u(0xdd94)..u(0x10fe)..u(0xdfff)..u(0x10fe)..u(0xebdc)..u(0x10fe)..u(0xebf4)..u(0x10fe)..u(0xec20)..u(0x10fe)..u(0xec24)..u(0x10fe)..u(0xec60)..u(0x10fe)..u(0x6bcc)..u(0x10a4)..u(0xed90)..u(0x10fe)..u(0xedd0)..u(0x10fe)..u(0xedf0)
s=s..u(0x10fe)..u(0xffff)..u(0x10fe)..u(0x2000)..u(0x10ff)..u(0x2ba0)..u(0x10ff)..u(0x7fff)..u(0x10ff)..u(0xc3ac)..u(0x10a5)..u(0xe3b0)..u(0x1107)..u(0xe5b0)..u(0x1107)..u(0xe7b0)..u(0x1107)..u(0xe9b0)..u(0x1107)..u(0xebb0)..u(0x1107)..u(0xedb0)..u(0x1107)..u(0xefb0)..u(0x1107)..u(0xf1b0)..u(0x1107)..u(0xf000)..u(0x1107)..u(0x0528)..u(0xffff)..u(0xf460)..u(0x1107)..u(0xf9c4)..u(0x1107)..u(0xff38)..u(0x1107)..u(0x5000)..u(0x1108)..u(0xb000)..u(0x10b3)..u(0x8710)..u(0x10b6)..u(0x8000)..u(0x10e0)..u(0xa974)..u(0x10e0)..u(0x1000)..u(0x10e1)..u(0x3cd4)
s=s..u(0x10e1)..u(0xc000)..u(0x10e1)..u(0xe9a8)..u(0x10e1)..u(0xd000)..u(0x10e9)..u(0xf190)..u(0x10e9)..u(0x4000)..u(0x1103)..u(0xb224)..u(0x10a0)..u(0xce8c)..u(0x1008)..u(0x5728)..u(0x10a1)..string.rep(u(0x00ff),2)..u(0x6580)..u(0x1103)..u(0x742e)..u(0x636e)..u(0x2e3b)..u(0x6e74)..u(0x66bc)..u(0x1103)..u(0x6888)..u(0x1103)..u(0xf000)..u(0x1104)..u(0x68e0)..u(0x1103)..u(0x692c)..u(0x1103)..u(0x0404)..u(0xffff)..u(0x78b8)..u(0x1103)..u(0x7000)..u(0x1103)..u(0x7910)..u(0x1103)..u(0x7960)..u(0x1103)..u(0xa000)..u(0x1103)..u(0x9dc4)..u(0x10a5)..u(0xaa80)..u(0x1103)
s=s..u(0xaac8)..u(0x1103)..u(0xab44)..u(0x1103)..u(0xabac)..u(0x1103)..u(0xabf4)..u(0x1103)..u(0xac4c)..u(0x1103)..u(0xaca4)..u(0x1103)..u(0xacfc)..u(0x1103)..u(0x98e4)..u(0x1104)..u(0x24ac)..u(0x1123)..u(0xf000)..u(0x1103)..u(0x9ad0)..u(0x1104)..u(0xd000)..u(0x1104)..u(0xf3c4)..u(0x1104)..u(0xa800)..u(0x11fd)..u(0x0254)..u(0x1105)..u(0x0007)..u(0x0451)..u(0xffff)..u(0x1105)..u(0x7bb4)..u(0x10aa)..u(0x03c0)..u(0x1105)..u(0x1000)..u(0x1105)..u(0x4254)..u(0x1105)..u(0xffff)..u(0x110a)..u(0xd394)..u(0x10ab)..u(0xf9ec)..u(0x110d)..u(0xfbec)..u(0x110d)
s=s..u(0xfdec)..u(0x110d)..u(0xffff)..u(0x110e)..u(0xffec)..u(0x110d)..u(0x01ec)..u(0x110e)..u(0x03ec)..u(0x110e)..string.rep(u(0x0023),2)..u(0x05ec)..u(0x110e)..u(0x1000)..u(0x110e)..string.rep(u(0x002a),2)..u(0x07ec)..u(0x110e)..u(0x0a9c)..u(0x110e)..u(0x0e94)..u(0x110e)..u(0xf000)..u(0x10b3)..string.rep(u(0x0069),2)..u(0x62f0)..u(0x10c0)..u(0x7000)..u(0x10c1)..u(0x8fb8)..u(0x10c1)..u(0xa000)..u(0x10c7)..u(0xca5c)..u(0x10c7)..u(0xe000)..u(0x10c8)..u(0x03f8)..u(0x10c9)..u(0x6000)..u(0x10cf)..u(0x8bd4)..u(0x10cf)..u(0xb000)..u(0x10d0)..u(0xda88)..u(0x10d0)..u(0xe000)..u(0x10f0)..u(0x0494)
s=s..u(0x10f1)..u(0x5000)..u(0x10f2)..u(0x6ecc)..u(0x10f2)..u(0x9000)..u(0x1104)..u(0x5678)..u(0x1234)..u(0x0038)..u(0x110a)..u(0x0209)..u(0xffff)..u(0x0903)..u(0xffff)..u(0x8000)..u(0x1105)..u(0x74f2)..u(0xf000)..u(0x1000)..u(0x110a)..u(0x0e7f)..u(0x19a2)..u(0x3070)..u(0x110e)..u(0x0503)..u(0xffff)..u(0x3000)..u(0x110e)..u(0x5000)..u(0x110e)..u(0x0124)..u(0xffff)..u(0x01f8)..u(0xffff)..u(0xf004)..u(0xe51f)..u(0xdc54)..u(0xffff)..u(0x00cc)..u(0xffff)..u(0xff1e)..u(0xe12f)..u(0x332c)..u(0xe51f)..u(0x5000)..u(0xe3e0)..u(0x5418)..u(0xe583)..u(0xa300)
s=s..u(0xe583)..u(0xa338)..u(0xe583)..u(0xa384)..u(0xe583)..u(0x2018)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0348)..u(0xe51f)..u(0xfa2b)..u(0xebff)..u(0x334c)..u(0xe51f)..u(0x20c8)..u(0xe3a0)..u(0x5664)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0358)..u(0xe51f)..u(0xfa25)..u(0xebff)..u(0x335c)..u(0xe51f)..u(0x235c)..u(0xe51f)..u(0xa7c4)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0364)..u(0xe51f)..u(0xfa1f)..u(0xebff)..u(0x3368)..u(0xe51f)..u(0x2368)..u(0xe51f)..u(0xa290)..u(0xe583)..u(0x3a01)..u(0xe283)..u(0xafb8)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0378)
s=s..u(0xe51f)..u(0xfa17)..u(0xebff)..u(0x337c)..u(0xe51f)..u(0x237c)..u(0xe51f)..u(0xad00)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xaa28)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x038c)..u(0xe51f)..u(0xfa0f)..u(0xebff)..u(0x3390)..u(0xe51f)..u(0x2390)..u(0xe51f)..u(0xa0e0)..u(0xe583)..u(0x3a01)..u(0xe283)..u(0xae08)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x03a0)..u(0xe51f)..u(0xfa07)..u(0xebff)..u(0x33a4)..u(0xe51f)..u(0x23a4)..u(0xe51f)..u(0xad34)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xaa5c)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x03b4)..u(0xe51f)..u(0xf9ff)
s=s..u(0xebff)..u(0x33b8)..u(0xe51f)..u(0x23b8)..u(0xe51f)..u(0xa214)..u(0xe583)..u(0x3a01)..u(0xe283)..u(0xaf3c)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x03c8)..u(0xe51f)..u(0xf9f7)..u(0xebff)..u(0x33cc)..u(0xe51f)..u(0x23cc)..u(0xe51f)..u(0xa51c)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa244)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x03dc)..u(0xe51f)..u(0xf9ef)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x03e8)..u(0xe51f)..u(0xf9eb)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x03f4)..u(0xe51f)..u(0xf9e7)..u(0xebff)..u(0x2044)
s=s..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0400)..u(0xe51f)..u(0xf9e3)..u(0xebff)..u(0x3404)..u(0xe51f)..u(0x2004)..u(0xe3a0)..u(0x241c)..u(0xe583)..u(0x2009)..u(0xe3a0)..u(0x2420)..u(0xe583)..u(0x2b02)..u(0xe3a0)..u(0x242c)..u(0xe583)..u(0x2028)..u(0xe242)..u(0x2430)..u(0xe583)..u(0x2424)..u(0xe51f)..u(0x8010)..u(0xe3a0)..u(0x2434)..u(0xe583)..u(0x242c)..u(0xe51f)..u(0x7020)..u(0xe3a0)..u(0x24b8)..u(0xe583)..u(0x8424)..u(0xe583)..u(0x7428)..u(0xe583)..u(0x2008)..u(0xe3a0)..u(0x1001)..u(0xe3a0)..u(0x0444)..u(0xe51f)..u(0xf9ce)..u(0xebff)..u(0x23a0)
s=s..u(0xe51f)..u(0x4001)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0454)..u(0xe51f)..u(0xb102)..u(0xe3a0)..u(0x6458)..u(0xe51f)..u(0x9002)..u(0xe3a0)..u(0x24d0)..u(0xe583)..u(0x459c)..u(0xe583)..u(0xa4e0)..u(0xe583)..u(0xa4f4)..u(0xe583)..u(0xa508)..u(0xe583)..u(0xa51c)..u(0xe583)..u(0xa530)..u(0xe583)..u(0xa544)..u(0xe583)..u(0xa558)..u(0xe583)..u(0xa56c)..u(0xe583)..u(0xa580)..u(0xe583)..u(0xa594)..u(0xe583)..u(0x2040)..u(0xe3a0)..u(0xf9b9)..u(0xebff)..u(0x2360)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0x049c)..u(0xe51f)..u(0x25f4)..u(0xe583)..u(0x2065)
s=s..u(0xe3a0)..u(0x2600)..u(0xe583)..u(0x2370)..u(0xe51f)..u(0x2678)..u(0xe583)..u(0x2374)..u(0xe51f)..u(0x267c)..u(0xe583)..u(0x206f)..u(0xe3a0)..u(0x2680)..u(0xe583)..u(0x2030)..u(0xe3a0)..u(0xf9ab)..u(0xebff)..u(0x2030)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x04d0)..u(0xe51f)..u(0xf9a7)..u(0xebff)..u(0x253f)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x04dc)..u(0xe51f)..u(0x2994)..u(0xe583)..u(0x2e7d)..u(0xe3a0)..u(0x299c)..u(0xe583)..u(0x2040)..u(0xe3a0)..u(0xf99f)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x04f8)..u(0xe51f)..u(0xf99b)
s=s..u(0xebff)..u(0x202c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0504)..u(0xe51f)..u(0xf997)..u(0xebff)..u(0x23c4)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0x0510)..u(0xe51f)..u(0x2b88)..u(0xe583)..u(0x2a02)..u(0xe3a0)..u(0x4b90)..u(0xe583)..u(0x2b98)..u(0xe583)..u(0xbb94)..u(0xe583)..u(0x3524)..u(0xe51f)..u(0x2040)..u(0xe3a0)..u(0xa95c)..u(0xe583)..u(0xf98b)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0538)..u(0xe51f)..u(0xf987)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0544)..u(0xe51f)..u(0xf983)..u(0xebff)..u(0x3548)
s=s..u(0xe51f)..u(0x2548)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0x23c0)..u(0xe583)..u(0x0550)..u(0xe51f)..u(0x2040)..u(0xe3a0)..u(0xf97c)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0560)..u(0xe51f)..u(0xf978)..u(0xebff)..u(0x2038)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x056c)..u(0xe51f)..u(0xf974)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0578)..u(0xe51f)..u(0xf970)..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0584)..u(0xe51f)..u(0xf96c)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0590)
s=s..u(0xe51f)..u(0xf968)..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x059c)..u(0xe51f)..u(0xf964)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x05a8)..u(0xe51f)..u(0xf960)..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x05b4)..u(0xe51f)..u(0xf95c)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x05c0)..u(0xe51f)..u(0xf958)..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x05cc)..u(0xe51f)..u(0xf954)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x05d8)..u(0xe51f)..u(0xf950)
s=s..u(0xebff)..u(0x2008)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x05e4)..u(0xe51f)..u(0xf94c)..u(0xebff)..u(0x2014)..u(0xe3a0)..u(0x1006)..u(0xe1a0)..u(0x05f0)..u(0xe51f)..u(0xf948)..u(0xebff)..u(0x35f4)..u(0xe51f)..u(0x1005)..u(0xe1a0)..u(0x4077)..u(0xe503)..u(0x2008)..u(0xe1a0)..u(0x0600)..u(0xe51f)..u(0xf942)..u(0xebff)..u(0x3604)..u(0xe51f)..u(0x1005)..u(0xe1a0)..u(0x5054)..u(0xe583)..u(0x2008)..u(0xe3a0)..u(0x0610)..u(0xe51f)..u(0xf93c)..u(0xebff)..u(0x3614)..u(0xe51f)..u(0x20ff)..u(0xe3a0)..u(0x4228)..u(0xe583)..u(0x2268)..u(0xe583)..u(0xa274)
s=s..u(0xe583)..u(0x206c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x062c)..u(0xe51f)..u(0xf933)..u(0xebff)..u(0x206c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0638)..u(0xe51f)..u(0xa460)..u(0xe583)..u(0xf92e)..u(0xebff)..u(0x3640)..u(0xe51f)..u(0x2007)..u(0xe1a0)..u(0x4838)..u(0xe583)..u(0x590c)..u(0xe583)..u(0x4910)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0654)..u(0xe51f)..u(0xf926)..u(0xebff)..u(0x3658)..u(0xe51f)..u(0x2538)..u(0xe51f)..u(0xa1df)..u(0xe503)..u(0x21d3)..u(0xe503)..u(0x3a01)..u(0xe283)..u(0x2c32)..u(0xe3a0)..u(0x2753)..u(0xe503)..u(0x2548)
s=s..u(0xe51f)..u(0xa653)..u(0xe503)..u(0x2723)..u(0xe503)..u(0x9437)..u(0xe503)..u(0x2008)..u(0xe1a0)..u(0x1000)..u(0xe3a0)..u(0x0688)..u(0xe51f)..u(0xf917)..u(0xebff)..u(0x2302)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0694)..u(0xe51f)..u(0x240f)..u(0xe503)..u(0x200c)..u(0xe3a0)..u(0xf911)..u(0xebff)..u(0x24d8)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0x06a8)..u(0xe51f)..u(0x23ff)..u(0xe503)..u(0x2032)..u(0xe3a0)..u(0x23f7)..u(0xe503)..u(0x24ec)..u(0xe51f)..u(0xb3fb)..u(0xe503)..u(0x23f3)..u(0xe503)..u(0x2fff)..u(0xe242)..u(0x23e3)..u(0xe503)..u(0xa3eb)
s=s..u(0xe503)..u(0x2008)..u(0xe3a0)..u(0xf903)..u(0xebff)..u(0x26d4)..u(0xe51f)..u(0x1004)..u(0xe1a0)..u(0x06d8)..u(0xe51f)..u(0x23d7)..u(0xe503)..u(0x26dc)..u(0xe51f)..u(0x23d3)..u(0xe503)..u(0x2008)..u(0xe3a0)..u(0xf8fb)..u(0xebff)..u(0x26e8)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0x06ec)..u(0xe51f)..u(0x226b)..u(0xe503)..u(0x2014)..u(0xe282)..u(0x2257)..u(0xe503)..u(0xa38f)..u(0xe503)..u(0xa2fb)..u(0xe503)..u(0xa2bf)..u(0xe503)..u(0xa26f)..u(0xe503)..u(0xa25b)..u(0xe503)..u(0x2007)..u(0xe1a0)..u(0xf8ee)..u(0xebff)..u(0x1005)..u(0xe1a0)..u(0x200c)
s=s..u(0xe3a0)..u(0x071c)..u(0xe51f)..u(0xf8ea)..u(0xebff)..u(0x3720)..u(0xe51f)..u(0x2e19)..u(0xe3a0)..u(0x4d13)..u(0xe503)..u(0x440b)..u(0xe503)..u(0x6d1b)..u(0xe503)..u(0x68d3)..u(0xe503)..u(0x3734)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0xab88)..u(0xe583)..u(0x073c)..u(0xe51f)..u(0xf8df)..u(0xebff)..u(0x3740)..u(0xe51f)..u(0x2740)..u(0xe51f)..u(0x4881)..u(0xe583)..u(0xaad3)..u(0xe503)..u(0x3004)..u(0xe083)..u(0x3a47)..u(0xe283)..u(0x92b4)..u(0xe583)..u(0x3a3f)..u(0xe283)..u(0x22a4)..u(0xe583)..u(0x1630)..u(0xe51f)..u(0x2040)..u(0xe3a0)..u(0x0764)
s=s..u(0xe51f)..u(0xf8d2)..u(0xebff)..u(0x5023)..u(0xe3a0)..u(0x2040)..u(0xe3a0)..u(0x163c)..u(0xe51f)..u(0x0774)..u(0xe51f)..u(0x402a)..u(0xe3a0)..u(0x53f0)..u(0xe583)..u(0xf8cb)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x1660)..u(0xe51f)..u(0x0788)..u(0xe51f)..u(0x45f0)..u(0xe583)..u(0xf8c6)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x1668)..u(0xe51f)..u(0x0798)..u(0xe51f)..u(0xf8c2)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x1684)..u(0xe51f)..u(0x07a4)..u(0xe51f)..u(0xf8be)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x1688)..u(0xe51f)..u(0x07b0)..u(0xe51f)..u(0x5bd4)
s=s..u(0xe583)..u(0xf8b9)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x16a8)..u(0xe51f)..u(0x07c0)..u(0xe51f)..u(0x4dd4)..u(0xe583)..u(0xf8b4)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x16b0)..u(0xe51f)..u(0x07d0)..u(0xe51f)..u(0xf8b0)..u(0xebff)..u(0x37d4)..u(0xe51f)..u(0x27d4)..u(0xe51f)..u(0xa444)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x07dc)..u(0xe51f)..u(0xf8aa)..u(0xebff)..u(0x206c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x07e8)..u(0xe51f)..u(0xf8a6)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x07f4)..u(0xe51f)..u(0xf8a2)..u(0xebff)..u(0x2678)
s=s..u(0xe51f)..u(0x2f7c)..u(0xe583)..u(0x3800)..u(0xe51f)..u(0xaba8)..u(0xe583)..u(0xabb4)..u(0xe583)..u(0x0232)..u(0xea00)..u(0x780c)..u(0xe51f)..u(0x3700)..u(0xe51f)..u(0x5000)..u(0xe3e0)..u(0x52c8)..u(0xe587)..u(0xa1b0)..u(0xe587)..u(0xa1e8)..u(0xe587)..u(0xa234)..u(0xe587)..u(0xa2f8)..u(0xe587)..u(0xa2fc)..u(0xe587)..u(0xa300)..u(0xe587)..u(0x5514)..u(0xe583)..u(0xa5ec)..u(0xe583)..u(0xa5f0)..u(0xe583)..u(0x3a29)..u(0xe283)..u(0xa674)..u(0xe583)..u(0xa68c)..u(0xe583)..u(0xa690)..u(0xe583)..u(0x2e33)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0854)
s=s..u(0xe51f)..u(0xf887)..u(0xebff)..u(0x3858)..u(0xe51f)..u(0x2f67)..u(0xe3a0)..u(0x2b80)..u(0xe583)..u(0xabb0)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa8d8)..u(0xe583)..u(0xa8f0)..u(0xe583)..u(0xa8f4)..u(0xe583)..u(0x20ac)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x087c)..u(0xe51f)..u(0xf87b)..u(0xebff)..u(0x3880)..u(0xe51f)..u(0x2e13)..u(0xe3a0)..u(0xaf90)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xacb8)..u(0xe583)..u(0xacd0)..u(0xe583)..u(0xacd4)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x089c)..u(0xe51f)..u(0xf871)..u(0xebff)..u(0x38a0)..u(0xe51f)..u(0x20b8)
s=s..u(0xe3a0)..u(0xabe4)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa90c)..u(0xe583)..u(0xa924)..u(0xe583)..u(0xa928)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x08bc)..u(0xe51f)..u(0xf867)..u(0xebff)..u(0x38c0)..u(0xe51f)..u(0x2f7b)..u(0xe3a0)..u(0x23c8)..u(0xe583)..u(0xa3cc)..u(0xe583)..u(0x3a02)..u(0xe283)..u(0xa0f4)..u(0xe583)..u(0xa10c)..u(0xe583)..u(0xa110)..u(0xe583)..u(0x20b8)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x08e4)..u(0xe51f)..u(0xf85b)..u(0xebff)..u(0x38e8)..u(0xe51f)..u(0x2004)..u(0xe3a0)..u(0xafd0)..u(0xe583)..u(0xafd4)..u(0xe583)..u(0xafd8)
s=s..u(0xe583)..u(0xafe4)..u(0xe583)..u(0xafe8)..u(0xe583)..u(0xaff8)..u(0xe583)..u(0xaffc)..u(0xe583)..u(0x3a01)..u(0xe283)..u(0xa004)..u(0xe583)..u(0xa008)..u(0xe583)..u(0xa000)..u(0xe583)..u(0x3a01)..u(0xe283)..u(0x22cc)..u(0xe583)..u(0x2009)..u(0xe3a0)..u(0xa228)..u(0xe583)..u(0xa22c)..u(0xe583)..u(0xa230)..u(0xe583)..u(0xa23c)..u(0xe583)..u(0xa240)..u(0xe583)..u(0xa250)..u(0xe583)..u(0xa254)..u(0xe583)..u(0xa258)..u(0xe583)..u(0xa25c)..u(0xe583)..u(0xa260)..u(0xe583)..u(0xa284)..u(0xe583)..u(0xa288)..u(0xe583)..u(0xa28c)..u(0xe583)..u(0xa298)
s=s..u(0xe583)..u(0xa29c)..u(0xe583)..u(0xa2ac)..u(0xe583)..u(0xa2b0)..u(0xe583)..u(0xa2b4)..u(0xe583)..u(0xa2b8)..u(0xe583)..u(0xa2bc)..u(0xe583)..u(0xa2c4)..u(0xe583)..u(0x22d0)..u(0xe583)..u(0x2020)..u(0xe3a0)..u(0x22d8)..u(0xe583)..u(0x2b02)..u(0xe3a0)..u(0x22dc)..u(0xe583)..u(0x2028)..u(0xe242)..u(0x22e0)..u(0xe583)..u(0x2994)..u(0xe51f)..u(0x4001)..u(0xe3a0)..u(0x22e4)..u(0xe583)..u(0x299c)..u(0xe51f)..u(0x8010)..u(0xe3a0)..u(0x2368)..u(0xe583)..u(0x2918)..u(0xe51f)..u(0x82d4)..u(0xe583)..u(0x2380)..u(0xe583)..u(0x29b0)..u(0xe51f)..u(0x1000)
s=s..u(0xe3a0)..u(0x2400)..u(0xe583)..u(0x29b8)..u(0xe51f)..u(0x09b8)..u(0xe51f)..u(0x24a4)..u(0xe583)..u(0x2065)..u(0xe3a0)..u(0x24b0)..u(0xe583)..u(0x29c4)..u(0xe51f)..u(0x4378)..u(0xe583)..u(0x2528)..u(0xe583)..u(0x29cc)..u(0xe51f)..u(0x437c)..u(0xe583)..u(0x252c)..u(0xe583)..u(0x206f)..u(0xe3a0)..u(0x2530)..u(0xe583)..u(0xa390)..u(0xe583)..u(0x2020)..u(0xe3a0)..u(0xa3a4)..u(0xe583)..u(0xa3b8)..u(0xe583)..u(0xa3cc)..u(0xe583)..u(0xa3e0)..u(0xe583)..u(0xa3f4)..u(0xe583)..u(0xa408)..u(0xe583)..u(0xa41c)..u(0xe583)..u(0xa430)..u(0xe583)..u(0xa444)
s=s..u(0xe583)..u(0x444c)..u(0xe583)..u(0xa464)..u(0xe583)..u(0xa468)..u(0xe583)..u(0xa46c)..u(0xe583)..u(0xa4b4)..u(0xe583)..u(0xa4b8)..u(0xe583)..u(0xf804)..u(0xebff)..u(0x2020)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0a2c)..u(0xe51f)..u(0xf800)..u(0xebff)..u(0x253f)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0a38)..u(0xe51f)..u(0x6703)..u(0xe3a0)..u(0xba3c)..u(0xe51f)..u(0x9002)..u(0xe3a0)..u(0x2844)..u(0xe583)..u(0x2e7d)..u(0xe3a0)..u(0x284c)..u(0xe583)..u(0xa874)..u(0xe583)..u(0x2028)..u(0xe3a0)..u(0xf7f4)..u(0xebff)..u(0x2028)..u(0xe3a0)..u(0x1000)
s=s..u(0xe3a0)..u(0x0a60)..u(0xe51f)..u(0xa8cc)..u(0xe583)..u(0xf7ef)..u(0xebff)..u(0x2028)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0a70)..u(0xe51f)..u(0xf7eb)..u(0xebff)..u(0x2a74)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0x0a78)..u(0xe51f)..u(0x2a38)..u(0xe583)..u(0x2102)..u(0xe3a0)..u(0x2a44)..u(0xe583)..u(0x2a02)..u(0xe3a0)..u(0x2a48)..u(0xe583)..u(0x4a40)..u(0xe583)..u(0x3a90)..u(0xe51f)..u(0x203c)..u(0xe3a0)..u(0xa89c)..u(0xe583)..u(0xf7de)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0aa4)..u(0xe51f)..u(0xf7da)..u(0xebff)..u(0x2038)
s=s..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0ab0)..u(0xe51f)..u(0xf7d6)..u(0xebff)..u(0x3ab4)..u(0xe51f)..u(0x2ab4)..u(0xe51f)..u(0xaa7c)..u(0xe583)..u(0x29f0)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x2038)..u(0xe3a0)..u(0x0ac4)..u(0xe51f)..u(0xf7ce)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0ad0)..u(0xe51f)..u(0xf7ca)..u(0xebff)..u(0x2038)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0adc)..u(0xe51f)..u(0xf7c6)..u(0xebff)..u(0x2034)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0ae8)..u(0xe51f)..u(0xf7c2)..u(0xebff)..u(0x2044)..u(0xe3a0)..u(0x1000)
s=s..u(0xe3a0)..u(0x0af4)..u(0xe51f)..u(0xf7be)..u(0xebff)..u(0x2044)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0b00)..u(0xe51f)..u(0x6bfc)..u(0xe583)..u(0x8c00)..u(0xe583)..u(0xf7b8)..u(0xebff)..u(0x2702)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0b14)..u(0xe51f)..u(0x2c54)..u(0xe583)..u(0x2020)..u(0xe3a0)..u(0x2c58)..u(0xe583)..u(0x2044)..u(0xe3a0)..u(0xf7b0)..u(0xebff)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0b30)..u(0xe51f)..u(0x6cac)..u(0xe583)..u(0x2cb0)..u(0xe583)..u(0x2044)..u(0xe3a0)..u(0xf7a9)..u(0xebff)..u(0x2c01)..u(0xe3a0)..u(0x1000)
s=s..u(0xe3a0)..u(0x0b48)..u(0xe51f)..u(0x6d04)..u(0xe583)..u(0x6b4c)..u(0xe51f)..u(0x2d08)..u(0xe583)..u(0xad54)..u(0xe583)..u(0xad58)..u(0xe583)..u(0x6d64)..u(0xe583)..u(0x6d68)..u(0xe583)..u(0x6d6c)..u(0xe583)..u(0x6d70)..u(0xe583)..u(0x6d74)..u(0xe583)..u(0x3b6c)..u(0xe51f)..u(0x2abc)..u(0xe51f)..u(0x45b8)..u(0xe583)..u(0x3902)..u(0xe283)..u(0x5520)..u(0xe583)..u(0x5528)..u(0xe583)..u(0x5684)..u(0xe583)..u(0x3a01)..u(0xe283)..u(0x5f44)..u(0xe583)..u(0x5f48)..u(0xe583)..u(0x3a01)..u(0xe283)..u(0x4858)..u(0xe583)..u(0x30ff)..u(0xe3a0)..u(0x3898)
s=s..u(0xe582)..u(0xa8a4)..u(0xe582)..u(0x2058)..u(0xe3a0)..u(0xf78b)..u(0xebff)..u(0x3afc)..u(0xe51f)..u(0x2058)..u(0xe3a0)..u(0xaa90)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0bbc)..u(0xe51f)..u(0xf785)..u(0xebff)..u(0x3bc0)..u(0xe51f)..u(0x201c)..u(0xe3a0)..u(0x5f3c)..u(0xe583)..u(0x4e68)..u(0xe583)..u(0x4f40)..u(0xe583)..u(0x1000)..u(0xe3a0)..u(0x0bd4)..u(0xe51f)..u(0xf77d)..u(0xebff)..u(0x3bd8)..u(0xe51f)..u(0x2bd8)..u(0xe51f)..u(0x345c)..u(0xe58b)..u(0x3c32)..u(0xe3a0)..u(0x3edc)..u(0xe58b)..u(0x3f81)..u(0xe3a0)..u(0x3f00)..u(0xe58b)..u(0x3bec)
s=s..u(0xe51f)..u(0xa450)..u(0xe58b)..u(0x3f0c)..u(0xe58b)..u(0x3bf4)..u(0xe51f)..u(0xafdc)..u(0xe58b)..u(0x2258)..u(0xe583)..u(0x2bfc)..u(0xe51f)..u(0x91f8)..u(0xe583)..u(0x225c)..u(0xe583)..u(0x2c04)..u(0xe51f)..u(0x5420)..u(0xe583)..u(0x23c4)..u(0xe583)..u(0x2014)..u(0xe282)..u(0x23d8)..u(0xe583)..u(0x2c14)..u(0xe51f)..u(0x5424)..u(0xe583)..u(0xa20c)..u(0xe583)..u(0xa218)..u(0xe583)..u(0xa254)..u(0xe583)..u(0x4290)..u(0xe583)..u(0x4294)..u(0xe583)..u(0xa2a0)..u(0xe583)..u(0xa334)..u(0xe583)..u(0xa370)..u(0xe583)..u(0xa3c0)..u(0xe583)..u(0xa3d4)
s=s..u(0xe583)..u(0xa400)..u(0xe583)..u(0xa404)..u(0xe583)..u(0x6914)..u(0xe583)..u(0x491c)..u(0xe583)..u(0x6d5c)..u(0xe583)..u(0x4224)..u(0xe582)..u(0x2a03)..u(0xe282)..u(0xa1b8)..u(0xe582)..u(0xa1d0)..u(0xe582)..u(0xa1d4)..u(0xe582)..u(0x1000)..u(0xe3a0)..u(0x20ac)..u(0xe3a0)..u(0x0c70)..u(0xe51f)..u(0xf74e)..u(0xebff)..u(0x2bdc)..u(0xe51f)..u(0x5c78)..u(0xe51f)..u(0x1c78)..u(0xe51f)..u(0xab5c)..u(0xe582)..u(0x2a01)..u(0xe282)..u(0x4eb0)..u(0xe582)..u(0x2a86)..u(0xe282)..u(0x98e4)..u(0xe585)..u(0x48e0)..u(0xe585)..u(0x0c90)..u(0xe51f)..u(0x18d4)
s=s..u(0xe582)..u(0x48d0)..u(0xe582)..u(0x1c80)..u(0xe51f)..u(0x2030)..u(0xe3a0)..u(0xf73f)..u(0xebff)..u(0x203c)..u(0xe3a0)..u(0x1c84)..u(0xe51f)..u(0x0cac)..u(0xe51f)..u(0xf73b)..u(0xebff)..u(0x2008)..u(0xe1a0)..u(0x1ca0)..u(0xe51f)..u(0x0cb8)..u(0xe51f)..u(0xf737)..u(0xebff)..u(0x9cbc)..u(0xe51f)..u(0x2020)..u(0xe3a0)..u(0x1ca8)..u(0xe51f)..u(0x0cc4)..u(0xe51f)..u(0xf732)..u(0xebff)..u(0x2024)..u(0xe3a0)..u(0x1cc4)..u(0xe51f)..u(0x0cd0)..u(0xe51f)..u(0xf72e)..u(0xebff)..u(0x2023)..u(0xe3a0)..u(0x2210)..u(0xe589)..u(0x1ccc)..u(0xe51f)..u(0x2024)
s=s..u(0xe3a0)..u(0x0ce4)..u(0xe51f)..u(0xf728)..u(0xebff)..u(0x202a)..u(0xe3a0)..u(0x2410)..u(0xe589)..u(0x1cf0)..u(0xe51f)..u(0x2008)..u(0xe1a0)..u(0x0cf4)..u(0xe51f)..u(0xf722)..u(0xebff)..u(0x8cf8)..u(0xe51f)..u(0x2020)..u(0xe3a0)..u(0x1cfc)..u(0xe51f)..u(0x0cfc)..u(0xe51f)..u(0xf71d)..u(0xebff)..u(0xaa80)..u(0xe589)..u(0x2040)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0d0c)..u(0xe51f)..u(0xf718)..u(0xebff)..u(0x2e13)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0d18)..u(0xe51f)..u(0xf714)..u(0xebff)..u(0x206c)..u(0xe3a0)..u(0x1000)..u(0xe3a0)..u(0x0008)
s=s..u(0xe1a0)..u(0xf710)..u(0xebff)..u(0x2d2c)..u(0xe51f)..u(0x9a07)..u(0xe289)..u(0x1d30)..u(0xe51f)..u(0xa574)..u(0xe588)..u(0xa578)..u(0xe588)..u(0xa57c)..u(0xe588)..u(0xa5d8)..u(0xe589)..u(0xa5e4)..u(0xe589)..u(0xa1ac)..u(0xe587)..u(0xa5f4)..u(0xe582)..u(0x2ac5)..u(0xe282)..u(0xa52c)..u(0xe582)..u(0x2a02)..u(0xe282)..u(0x1264)..u(0xe582)..u(0xa254)..u(0xe582)..u(0xa26c)..u(0xe582)..u(0xa270)..u(0xe582)..u(0x1000)..u(0xe3a0)..u(0x20a4)..u(0xe3a0)..u(0x0d70)..u(0xe51f)..u(0xf6fb)..u(0xebff)..u(0x2d74)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0xa1f4)
s=s..u(0xe582)..u(0x2a01)..u(0xe282)..u(0xaf1c)..u(0xe582)..u(0xaf34)..u(0xe582)..u(0xaf38)..u(0xe582)..u(0x0d8c)..u(0xe51f)..u(0x20b0)..u(0xe3a0)..u(0xf6f1)..u(0xebff)..u(0x2d94)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0xac98)..u(0xe582)..u(0x2a02)..u(0xe282)..u(0xa9c0)..u(0xe582)..u(0xa9d8)..u(0xe582)..u(0xa9dc)..u(0xe582)..u(0x0dac)..u(0xe51f)..u(0x20a4)..u(0xe3a0)..u(0xf6e7)..u(0xebff)..u(0x2db4)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0xa634)..u(0xe582)..u(0x2a02)..u(0xe282)..u(0xa35c)..u(0xe582)..u(0xa374)..u(0xe582)..u(0xa378)..u(0xe582)..u(0x0dcc)
s=s..u(0xe51f)..u(0x20b0)..u(0xe3a0)..u(0xf6dd)..u(0xebff)..u(0x2dd4)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0xae00)..u(0xe582)..u(0x2a02)..u(0xe282)..u(0xab28)..u(0xe582)..u(0xab40)..u(0xe582)..u(0xab44)..u(0xe582)..u(0xabc4)..u(0xe582)..u(0x0df0)..u(0xe51f)..u(0x2094)..u(0xe3a0)..u(0xf6d2)..u(0xebff)..u(0x2df8)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0xacc4)..u(0xe582)..u(0x2a02)..u(0xe282)..u(0xa9ec)..u(0xe582)..u(0xaa04)..u(0xe582)..u(0xaa08)..u(0xe582)..u(0x0e10)..u(0xe51f)..u(0x20b0)..u(0xe3a0)..u(0xf6c8)..u(0xebff)..u(0x2e18)..u(0xe51f)..u(0x1000)
s=s..u(0xe3a0)..u(0xa6d0)..u(0xe582)..u(0x2a02)..u(0xe282)..u(0xa3f8)..u(0xe582)..u(0xa410)..u(0xe582)..u(0xa414)..u(0xe582)..u(0x0e30)..u(0xe51f)..u(0x20a8)..u(0xe3a0)..u(0xf6be)..u(0xebff)..u(0x2e38)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0xa108)..u(0xe582)..u(0x2a01)..u(0xe282)..u(0xae30)..u(0xe582)..u(0xae48)..u(0xe582)..u(0xae4c)..u(0xe582)..u(0x0e50)..u(0xe51f)..u(0x20b8)..u(0xe3a0)..u(0xf6b4)..u(0xebff)..u(0x2e58)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0xab30)..u(0xe582)..u(0x2e60)..u(0xe51f)..u(0x0e60)..u(0xe51f)..u(0x2b38)..u(0xe58b)..u(0x2302)
s=s..u(0xe3a0)..u(0x2220)..u(0xe583)..u(0x2e6c)..u(0xe51f)..u(0xa224)..u(0xe583)..u(0x2230)..u(0xe583)..u(0x2102)..u(0xe3a0)..u(0x2234)..u(0xe583)..u(0x2032)..u(0xe3a0)..u(0x2238)..u(0xe583)..u(0x2e84)..u(0xe51f)..u(0xa228)..u(0xe583)..u(0x223c)..u(0xe583)..u(0x2fff)..u(0xe242)..u(0x224c)..u(0xe583)..u(0xa22c)..u(0xe583)..u(0xa244)..u(0xe583)..u(0xa250)..u(0xe583)..u(0x3ea0)..u(0xe51f)..u(0x2028)..u(0xe3a0)..u(0xab8c)..u(0xe583)..u(0x3a01)..u(0xe283)..u(0x4e5c)..u(0xe583)..u(0x6eb4)..u(0xe583)..u(0x6eb8)..u(0xe583)..u(0xa00c)..u(0xe585)..u(0xa010)
s=s..u(0xe585)..u(0xf693)..u(0xebff)..u(0x3004)..u(0xe3a0)..u(0x38dc)..u(0xe585)..u(0x2ecc)..u(0xe51f)..u(0x3ecc)..u(0xe51f)..u(0x1000)..u(0xe3a0)..u(0x215c)..u(0xe583)..u(0x2403)..u(0xe3a0)..u(0x2160)..u(0xe583)..u(0x2edc)..u(0xe51f)..u(0x0edc)..u(0xe51f)..u(0x2164)..u(0xe583)..u(0x3ee0)..u(0xe51f)..u(0x2020)..u(0xe3a0)..u(0x35b8)..u(0xe588)..u(0x3004)..u(0xe3a0)..u(0x39e8)..u(0xe588)..u(0x3ef0)..u(0xe51f)..u(0xa03c)..u(0xe583)..u(0xa040)..u(0xe583)..u(0xa04c)..u(0xe583)..u(0xf67e)..u(0xebff)..u(0x3f00)..u(0xe51f)..u(0xaa40)..u(0xe583)..u(0xaa50)
s=s..u(0xe583)..u(0xaa60)..u(0xe583)..u(0xaa70)..u(0xe583)..u(0xaa80)..u(0xe583)..u(0xaa90)..u(0xe583)..u(0xaaa0)..u(0xe583)..u(0xaab0)..u(0xe583)..u(0xaac0)..u(0xe583)..u(0xaad0)..u(0xe583)..u(0xaae0)..u(0xe583)..u(0xaaf0)..u(0xe583)..u(0xab00)..u(0xe583)..u(0xab10)..u(0xe583)..u(0xab20)..u(0xe583)..u(0x46b8)..u(0xe589)..u(0x0002)..u(0xea00)..u(0x3004)..u(0xe59d)..u(0x0001)..u(0xe353)..u(0x0015)..u(0xda00)..u(0x3f50)..u(0xe51f)..u(0x2004)..u(0xe59d)..u(0x3003)..u(0xe08f)..u(0x3102)..u(0xe793)..u(0x2f5c)..u(0xe51f)..u(0x1008)..u(0xe283)..u(0x2002)
s=s..u(0xe08f)..u(0x100c)..u(0xe582)..u(0x1000)..u(0xe593)..u(0x1000)..u(0xe582)..u(0x1f70)..u(0xe51f)..u(0x0004)..u(0xe593)..u(0x1000)..u(0xe583)..u(0x0004)..u(0xe582)..u(0x0f7c)..u(0xe51f)..u(0xffff)..u(0xe08f)..u(0x0004)..u(0xe583)..u(0x1008)..u(0xe582)..u(0xf66c)..u(0xebff)..u(0xf66b)..u(0xebff)..u(0x3201)..u(0xe3a0)..u(0xff33)..u(0xe12f)..u(0x3f98)..u(0xe51f)..u(0x2004)..u(0xe59d)..u(0x3003)..u(0xe08f)..u(0x3102)..u(0xe083)..u(0x3010)..u(0xe593)..u(0x2fa8)..u(0xe51f)..u(0x2000)..u(0xe583)..u(0xffe1)..u(0xeaff)..u(0x303c)..u(0xe59f)..u(0x203c)
s=s..u(0xe59f)..u(0x3003)..u(0xe08f)..u(0x3002)..u(0xe793)..u(0x3000)..u(0xe593)..u(0x0006)..u(0xe353)..u(0x302c)..u(0x059f)..u(0x0007)..u(0x0a00)..u(0x0007)..u(0xe353)..u(0x3024)..u(0x059f)..u(0x0004)..u(0x0a00)..u(0xc020)..u(0xe59f)..u(0x2020)..u(0xe59f)..u(0x0008)..u(0xe353)..u(0x3002)..u(0x01a0)..u(0x300c)..u(0x11a0)..u(0xff13)..u(0xe12f)..u(0x01a8)..string.rep(u(0xffff),3)..u(0x6acc)..u(0x1040)..u(0x750c)..u(0x1040)..u(0x53c0)..u(0x1040)..u(0x4950)..u(0x1040)..u(0x3040)..u(0xe59f)..u(0x2040)..u(0xe59f)..u(0x3003)..u(0xe08f)..u(0x3002)..u(0xe793)..u(0x2000)
s=s..u(0xe593)..u(0x0006)..u(0xe352)..u(0x0006)..u(0x0a00)..u(0x0007)..u(0xe352)..u(0x0006)..u(0x0a00)..u(0x3024)..u(0xe59f)..u(0x0008)..u(0xe352)..u(0x0020)..u(0xe59f)..u(0x0003)..u(0x01a0)..u(0xff1e)..u(0xe12f)..u(0x0018)..u(0xe59f)..u(0xff1e)..u(0xe12f)..u(0x0014)..u(0xe59f)..u(0xff1e)..u(0xe12f)..u(0x014c)..string.rep(u(0xffff),3)..u(0xc858)..u(0x103f)..u(0xd2c8)..u(0x103f)..u(0xe9d4)..u(0x103f)..u(0xf414)..u(0x103f)..u(0x2598)..u(0x1001)..u(0x251c)..u(0x1001)..u(0x23bc)..u(0x1001)..u(0x2370)..u(0x1001)..u(0x5df4)..u(0x1013)..u(0x6418)..u(0x1013)..u(0x6272)
s=s..u(0x2f00)..u(0x6f64)..u(0x7563)..u(0x656d)..u(0x746e)..u(0x2f73)..u(0x646e)..u(0x656c)..u(0x7373)..u(0x6e2f)..u(0x6c64)..u(0x7365)..u(0x5f73)..u(0x6572)..u(0x6f73)..u(0x7275)..u(0x6563)..u(0x5f73)..u(0x2e33)..u(0x2e36)..u(0x6e74)..u(0x0073)..u(0x652f)..u(0x6178)..u(0x6d6d)..u(0x646f)..u(0x2f65)..u(0x7375)..u(0x2f72)..u(0x7250)..u(0x7365)..u(0x2d73)..u(0x6f74)..u(0x542d)..u(0x7365)..u(0x2f74)..u(0x646e)..u(0x656c)..u(0x7373)..u(0x725f)..u(0x7365)..u(0x756f)..u(0x6372)..u(0x7365)..u(0x335f)..u(0x362e)..u(0x742e)..u(0x736e)..u(0x4500)..u(0x4158)
s=s..u(0x2c4d)..u(0x7920)..u(0x756f)..u(0x7627)..u(0x2065)..u(0x6f66)..u(0x6772)..u(0x746f)..u(0x6574)..u(0x206e)..u(0x6f74)..u(0x7420)..u(0x6172)..u(0x736e)..u(0x6566)..u(0x2072)..u(0x2066)..string.rep(u(0x2020),8)..u(0x6e27)..u(0x6c64)..u(0x7365)..u(0x5f73)..u(0x6572)..u(0x6f73)..u(0x7275)..u(0x6563)..u(0x5f73)..u(0x2e33)..u(0x2736)..u(0x2021)..u(0x644e)..u(0x656c)..u(0x7373)..u(0x7720)..u(0x6e6f)..u(0x7427)..u(0x6220)..u(0x2065)..u(0x6e69)..u(0x7473)..u(0x6c61)..u(0x656c)..u(0x2e64)..string.rep(u(0xffff),13)..u(0x28c4)..string.rep(u(0xffff),7)
s=s..string.rep(u(0x0001),12636)
s_ncas = u(0x0d14) .. u(0x10e6)
s_cas = u(0x4d14) .. u(0x10e3)
s_ncascx = u(0xee5c) .. u(0x110a)
s_cascx = u(0x2e5c) .. u(0x1111)